import requests
import os
import base64
import json

# Función para aplicar XOR con una clave
def aplicar_xor(data, clima):
    return bytes([b ^ clima for b in data])

# Función para desencriptar la cadena con base64 y reversión XOR
def desca(texto_base64):
    # Decodificar base64
    texto_xor = base64.b64decode(texto_base64)
    # Aplicar XOR inverso
    texto_original = aplicar_xor(texto_xor, 18)
    return texto_original.decode()

# Función para obtener la IP pública automáticamente
def get_user_ip():
    try:
        # Servicio gratuito para obtener la IP pública del usuario
        response = requests.get("https://api.ipify.org?format=json")
        ip_data = response.json()
        return ip_data.get('ip')
    except requests.exceptions.RequestException:
        return None

def login_and_get_data():
    API_KEY = os.environ.get("API_KEY")
    ip_address = get_user_ip()  # Obtener la IP automáticamente
    if not ip_address:
        return "No se pudo obtener la IP del usuario.", False  # En caso de error al obtener la IP
    # URL del script PHP
    url = "http://aitestingdata553.byethost15.com/login.php"

    # Headers personalizados
    headers = {
        "Host": "aitestingdata553.byethost15.com",
        "Connection": "keep-alive",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/html, application/xhtml+xml, application/xml;q=0.9, image/avif, image/webp, image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    # Cookies a enviar en la solicitud
    cookies = {
        "__test": "4bab52df27ad25263cb4337ffe7d7f90"
    }

    # Parámetros de la solicitud POST
    data = {
        'api': API_KEY,  # Usando la API pasada como argumento
        'ip': ip_address  # Usando la IP pasada como argumento
    }

    try:
        # Realizar la solicitud POST con los headers, cookies y los parámetros de datos
        response = requests.post(url, headers=headers, cookies=cookies, data=data, timeout=30)

        # Verificar la respuesta
        if response.status_code == 200:
            # Intentar obtener la respuesta JSON
            response_json = response.json()
            if response_json.get('success', False):
                # Retornar el contenido de 'data' si la solicitud fue exitosa
                result = desca(response_json['data'])
                #variables = result.split(".")
                decoded_data = [desca(item) for item in result.split(".")]
                return  decoded_data, True    #desca(response_json['data'])
            else:
                # Si la respuesta es exitosa pero no contiene el campo 'data'
                return f"Error: {response_json.get('message', 'No data found')}", False
        else:
            return f"Error al acceder al servidor. Código de estado: {response.status_code}", False

    except requests.exceptions.RequestException as e:
        return f"Se produjo un error en la solicitud POST: {e}", False


import requests
import hashlib
import os


def iniciar_sesion(account, password):
    url = "https://piclumen.com/api/user/login"

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": "",  # Agrega tu token aquí si es necesario
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryG0HDGc4eqwD1nY07",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/account",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    # Generar el hash MD5 de la contraseña
    #hashed_password = hashlib.md5(password.encode('utf-8')).hexdigest()

    # Cuerpo de la solicitud con la estructura exacta requerida
    payload = (
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07\r\n"
        f"Content-Disposition: form-data; name=\"account\"\r\n\r\n"
        f"{account}\r\n"
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07\r\n"
        f"Content-Disposition: form-data; name=\"password\"\r\n\r\n"
        f"{password}\r\n"
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07--\r\n"
    )

    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, data=payload)

    # Manejar la respuesta
    if response.ok:
        respuesta_json = response.json()
        if "data" in respuesta_json:
            # Extraer token y userId
            tokens = respuesta_json["data"].get("token", None)
            os.environ["TOKEN_PIC"] = tokens
            user_ids = respuesta_json["data"].get("userId", None)
            os.environ["USER_ID_PIC"] = user_ids
            return tokens, user_ids
        else:
            return None, None
    else:
        return None, None




import os
from logs import *
import shutil
import gradio as gr
import random
import requests
import time
from IPython.display import Image, display
from flux import generar_imagen_flux
from linearv1 import generar_imagen_linearv1
from ponyv6 import generar_imagen_ponyv6
from realisticv2 import generar_imagen_realisticv2
from animev2 import generar_imagen_animev2
from pic_reg import configurar_usuario
from upscaler import upload_file_upscaler, upscale_image
from remove import remove_image, upload_file_remove
import subprocess
from PIL import Image
import gradio as gr
import cv2
import sys
import time
#sys.path.append('/tmp/IA')
import shutil
from runway_image_to_video import gen_runway_image_to_video
from runway_image2_to_video import gen_runway_image2_to_video
from runway_upload_image import subir_media_runway
from runway_upload_image2 import subir_media_runway2
from flux_pro import gen_flux_pro_image

def load_flux_ration(selected_ration):
    # Mapeo de idiomas a directorios
    aspe_rations = {
        "1:1": "1024x1024",
        "16:9": "1344x768",
        "9:16": "768x1344",
        "4:3": "1280x960",
        "3:4": "960x1280"
    }
    resolution = aspe_rations.get(selected_ration)

    return resolution

# Función para crear el archivo .zip de la carpeta de imágenes
def create_zip_of_images_fluxpro():
        # Crear el archivo zip
        zip_filename = "/tmp/generated_fluxpro.zip"
        shutil.make_archive(zip_filename.replace(".zip", ""), 'zip', "/tmp/img_flux_pro")  # Comprimir la carpeta

        # Devolver el archivo comprimido para ser descargado
        return zip_filename

    # Función para ejecutar cuando se presiona el botón "Save All"
def on_save_fluxpro_click():
        # Llamar a la función para crear el archivo zip
        zip_file = create_zip_of_images_fluxpro()

        # Devolver el archivo para que el componente gr.File pueda manejarlo
        return zip_file  # El archivo zip será devuelto al componente gr.File para su descarga

# Función para ejecutar cuando se presiona el botón "Generate"
def on_generate_fluxpro_click(prompt, selected_ration, models_type):

        wid_hei = load_flux_ration(selected_ration)
        ancho, alto = map(int, wid_hei.split('x'))
        print(ancho)
        print(alto)
        width = ancho
        height = alto

        gen_flux_pro_image(prompt, width, height, selected_ration, models_type)
        video_output1 = os.environ.get("DIR_IMAGEE_FLUX_PRO")

        gen_flux_pro_image(prompt, width, height, selected_ration, models_type)
        video_output2 = os.environ.get("DIR_IMAGEE_FLUX_PRO")

        output_textbox3 = "Successful generation"

        # Devolver las actualizaciones
        return video_output1, video_output2, output_textbox3

def divide_seconds(minute):
    # Calcular segundos totales
    total_seconds = minute * 60
    # Calcular cuántos intervalos de 3 segundos caben
    intervals = total_seconds // 3  # Número de divisiones en intervalos de 3 segundos
    return intervals


def actualizar_length(tipo_model):
    if tipo_model == "Pro":
        return gr.update(visible=False, value="5")
    return gr.update(visible=True)

def process_upload_image1_runway(image):
    jpg_path = "/tmp/img_fragmento.jpg"

    try:
        if image.format != "JPEG":
            image = image.convert("RGB")
        image.save(jpg_path, "JPEG", quality=100)
        if os.path.exists(jpg_path):
            print(f"Imagen guardada correctamente")

            # Obtener las dimensiones de la imagen
            width, height = image.size

            os.environ["WIDTH_IMG1"] = str(width)
            os.environ["HEIGHT_IMG1"] = str(height)
            os.environ["IMG1"] = jpg_path

            print(f"Coordenadas guardadas correctamente")

        return None
    except Exception as e:
        print(f"Error al procesar la imagen: {str(e)}")
        return None


def process_upload_image2_runway(image):
    jpg_path2 = "/tmp/img_fragmento2.jpg"

    try:
        if image.format != "JPEG":
            image = image.convert("RGB")
        image.save(jpg_path2, "JPEG", quality=100)
        if os.path.exists(jpg_path2):
            print(f"Imagen guardada correctamente")

            # Obtener las dimensiones de la imagen
            width2, height2 = image.size

            # Guardar las coordenadas en un archivo de texto
            os.environ["WIDTH_IMG2"] = str(width2)
            os.environ["HEIGHT_IMG2"] = str(height2)
            os.environ["IMG2"] = jpg_path2

            print(f"Coordenadas guardadas correctamente")

    except Exception as e:
        print(f"Error al procesar la imagen: {str(e)}")


def run_recreate_img_video_runway(subject, aspect_ratio,  length, loop_video, prompt_upsampling, slider_failed):
    os.environ["FAILED_TIME"] = str(divide_seconds(slider_failed))
    dir_img = os.environ.get("IMG1")
    # Ejecutar la función
    subir_media_runway(dir_img) #

    media_id_img = os.environ.get("MEDIA_ID_IMG")
    assetKey_ids = os.environ.get("ASSET_KEY_ID")
    print(media_id_img)
    print(assetKey_ids)

    assetKey_id = os.environ.get("ASSET_KEY_ID")
    print(assetKey_id)
    model_type="RunwayVideoGen3"
    elements_0="subject"
    elements_1="runwayStartKeyframe"
    elements_2="runwayEndKeyframe"
    elements_3="runwayVideoGen3Settings"
    #aspect_ratio="16:9"
    width=1344
    height=768
    subject="A stylish woman walks down a Tokyo street filled with warm glowing neon and animated city signage. She wears a black leather jacket, a long red dress, and black boots, and carries a black purse. She wears sunglasses and red lipstick. She walks confidently and casually. The street is damp and reflective, creating a mirror effect of the colorful lights. Many pedestrians walk about."
    evolve=4
    version=1
    video_type="Video"
    motion_magnitude=4
    #length=5
    stable_diffusion_checkpoint="dreamshaper"
    guidance=3
    steps=38
    denoise=0.4
    creativity_scale=5
    #loop_video=False
    audio_reactivity=6
    scale_factor=2
    topaz_model="Standard V2"
    topaz_face_enhancement_creativity=0
    flux_pro_model="flux-pro-1.1-ultra"
    #prompt_upsampling=True
    userProvidedStartingFrame = assetKey_id
    form_index=1
    starting_frame_weights="0.8"
    name="Runway Video"
    # Example usage:
    gen_runway_image_to_video(model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, name, userProvidedStartingFrame)

    media_idss = os.environ.get("MEDIA_ID")

    directory_video = os.environ.get("DIR_VIDEO")

    failed_mp4 = os.environ.get("FAILDE_VIDEO")
    if failed_mp4 == "failed":
      directory_video="/tmp/failded.mp4"

    print(f"mediaId: {media_idss}")

    # Devuelve la ruta del video y un mensaje
    return directory_video, "Video creado con éxito"

def run_extend_runway(subject, aspect_ratio,  length, loop_video, prompt_upsampling, slider_failed):
    os.environ["FAILED_TIME"] = str(divide_seconds(slider_failed))

    directory_video = os.environ.get("DIR_VIDEO")
    # Llamada a la función
    get_last_frame(directory_video)
    dir_img = os.environ.get("IMG1")
    # Ejecutar la función
    subir_media_runway(dir_img) #

    media_id_img = os.environ.get("MEDIA_ID_IMG")
    assetKey_ids = os.environ.get("ASSET_KEY_ID")
    print(media_id_img)
    print(assetKey_ids)

    assetKey_id = os.environ.get("ASSET_KEY_ID")
    print(assetKey_id)
    model_type="RunwayVideoGen3"
    elements_0="subject"
    elements_1="runwayStartKeyframe"
    elements_2="runwayEndKeyframe"
    elements_3="runwayVideoGen3Settings"
    #aspect_ratio="16:9"
    width=1344
    height=768
    #subject="A stylish woman walks down a Tokyo street filled with warm glowing neon and animated city signage. She wears a black leather jacket, a long red dress, and black boots, and carries a black purse. She wears sunglasses and red lipstick. She walks confidently and casually. The street is damp and reflective, creating a mirror effect of the colorful lights. Many pedestrians walk about."
    evolve=4
    version=1
    video_type="Video"
    motion_magnitude=4
    #length=5
    stable_diffusion_checkpoint="dreamshaper"
    guidance=3
    steps=38
    denoise=0.4
    creativity_scale=5
    #loop_video=False
    audio_reactivity=6
    scale_factor=2
    topaz_model="Standard V2"
    topaz_face_enhancement_creativity=0
    flux_pro_model="flux-pro-1.1-ultra"
    #prompt_upsampling=True
    userProvidedStartingFrame = assetKey_id
    form_index=1
    starting_frame_weights="0.8"
    name="Runway Video"
    # Example usage:
    gen_runway_image_to_video(model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, name, userProvidedStartingFrame)

    media_idss = os.environ.get("MEDIA_ID")

    directory_video = os.environ.get("DIR_VIDEO")

    failed_mp4 = os.environ.get("FAILDE_VIDEO")
    if failed_mp4 == "failed":
      directory_video="/tmp/failded.mp4"

    print(f"mediaId: {media_idss}")

    # Devuelve la ruta del video y un mensaje
    return directory_video, "Video creado con éxito"

def run_generate_img_video_runway(subject, aspect_ratio, length, loop_video, prompt_upsampling, add_end_frame, slider_failed):
    os.environ["FAILED_TIME"] = str(divide_seconds(slider_failed))

    if add_end_frame:
      jpg_path2 = os.environ.get("IMG2")
      subir_media_runway2(jpg_path2)
      media_id_img2 = os.environ.get("MEDIA_ID_IMG2")

      assetKey_id_2 = os.environ.get("ASSET_KEY_ID2")
      runway_EndKeyframe = assetKey_id_2
      starting_frame_weights="0.8"
      runway_EndKeyframeWeights="0.8"
    else:
      luma_EndKeyframe = ""
      starting_frame_weights="0.8"
      runway_EndKeyframeWeights=""

    jpg_path = os.environ.get("IMG1")
    subir_media_runway(jpg_path)

    media_id_img = os.environ.get("MEDIA_ID_IMG")
    assetKey_id = os.environ.get("ASSET_KEY_ID")
    userProvidedStartingFrame = assetKey_id

    print(assetKey_id)
    model_type="RunwayVideoGen3"
    elements_0="subject"
    elements_1="runwayStartKeyframe"
    elements_2="runwayEndKeyframe"
    elements_3="runwayVideoGen3Settings"
    #aspect_ratio="16:9"
    width=1344
    height=768
    #subject="un hombre caminando bajo la lluvia"
    evolve=4
    version=1
    video_type="Video"
    motion_magnitude=4
    #length=5
    stable_diffusion_checkpoint="dreamshaper"
    guidance=3
    steps=38
    denoise=0.4
    creativity_scale=5
    #loop_video=False
    audio_reactivity=6
    scale_factor=2
    topaz_model="Standard V2"
    topaz_face_enhancement_creativity=0
    flux_pro_model="flux-pro-1.1-ultra"
    #prompt_upsampling=True
    form_index=1
    name="Runway Video"
    # Example usage:
    if add_end_frame:
      gen_runway_image2_to_video(model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, runway_EndKeyframeWeights, name, userProvidedStartingFrame, runway_EndKeyframe)
    else:
      gen_runway_image_to_video(model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, name, userProvidedStartingFrame)

    media_idss = os.environ.get("MEDIA_ID")

    directory_video = os.environ.get("DIR_VIDEO")

    failed_mp4 = os.environ.get("FAILDE_VIDEO")
    if failed_mp4 == "failed":
      directory_video="/tmp/failded.mp4"

    print(f"mediaId: {media_idss}")

    # Devuelve la ruta del video y un mensaje
    return directory_video, "Video creado con éxito"

# Función para unir videos numerados y limpiar la carpeta
def join_videos_and_clean(video_folder, output_file):
    try:
        # Verificar si la carpeta existe
        if not os.path.exists(video_folder):
            return "Error: La carpeta no existe.", None

        # Obtener y ordenar archivos MP4 numerados
        video_files = sorted([f for f in os.listdir(video_folder) if f.endswith(".mp4")])
        if not video_files:
            return "Error: No se encontraron archivos MP4 en la carpeta.", None

        # Crear archivo de lista para FFmpeg
        list_file_path = os.path.join(video_folder, "file_list.txt")
        with open(list_file_path, "w") as list_file:
            for video in video_files:
                list_file.write(f"file '{os.path.join(video_folder, video)}'\n")

        # Ejecutar FFmpeg para unir los videos
        command = [
            "ffmpeg",
            "-f", "concat",
            "-safe", "0",
            "-i", list_file_path,
            "-c", "copy",
            output_file
        ]
        subprocess.run(command, check=True)

        # Eliminar archivo de lista temporal
        os.remove(list_file_path)

        # Eliminar los archivos MP4 de la carpeta después de la unión
        for video in video_files:
            os.remove(os.path.join(video_folder, video))

        return "Videos unidos y archivos eliminados exitosamente.", output_file
    except subprocess.CalledProcessError as e:
        return f"Error al unir los videos con FFmpeg: {str(e)}", None
    except Exception as e:
        return f"Error inesperado: {str(e)}", None

# Función conectada al botón Save
def run_save_and_display():
    directory_video = os.environ.get("DIR_VIDEO")

    save_video_extend(directory_video)

    video_folder = "/tmp/video_extend"
    output_file = "/tmp/final_video.mp4"  # Archivo final fuera de la carpeta
    message, output_path = join_videos_and_clean(video_folder, output_file)
    return message, output_path



def save_video_extend(video_path):
    import os
    import cv2

    # Verificar si la carpeta de destino existe, si no, crearla
    target_folder = "/tmp/video_extend"
    if not os.path.exists(target_folder):
        os.makedirs(target_folder)

    # Encontrar el siguiente nombre secuencial disponible
    existing_files = os.listdir(target_folder)
    existing_files = [f for f in existing_files if f.endswith(".mp4")]
    if existing_files:
        # Obtener el número más alto y agregar uno
        existing_numbers = [int(f.replace('.mp4', '')) for f in existing_files]
        next_number = max(existing_numbers) + 1
    else:
        next_number = 1

    # Crear el nombre del nuevo archivo
    new_filename = f"{next_number:05d}.mp4"  # 00001.mp4, 00002.mp4, ...

    # Leer el video original
    cap = cv2.VideoCapture(video_path)
    if not cap.isOpened():
        raise ValueError(f"Error al abrir el archivo de video: {video_path}")

    # Obtener parámetros del video original
    fps = cap.get(cv2.CAP_PROP_FPS)  # FPS del video original
    width = int(cap.get(cv2.CAP_PROP_FRAME_WIDTH))
    height = int(cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
    fourcc = cv2.VideoWriter_fourcc(*"mp4v")  # Formato MP4

    # Configurar el escritor de video con los mismos parámetros
    output_path = os.path.join(target_folder, new_filename)
    out = cv2.VideoWriter(output_path, fourcc, fps, (width, height))

    # Leer y escribir cada frame
    while cap.isOpened():
        ret, frame = cap.read()
        if not ret:
            break
        out.write(frame)

    # Liberar recursos
    cap.release()
    out.release()

    print(f"Video guardado en: {output_path}")
    return output_path


# Función para obtener el último frame de un video
def get_last_frame(video_path):
    try:
        cap = cv2.VideoCapture(video_path)
        frame_count = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
        cap.set(cv2.CAP_PROP_POS_FRAMES, frame_count - 1)
        ret, frame = cap.read()
        cap.release()

        if ret:
            # Convertimos el frame a formato RGB y lo guardamos
            img = Image.fromarray(cv2.cvtColor(frame, cv2.COLOR_BGR2RGB))
            img.save("/tmp/img_fragmento.jpg", format="JPEG", quality=100)  # Guardar con calidad al 100%
            print(f"Último frame guardado en: img_fragmento.jpg")
            os.environ["IMG1"] = "/tmp/img_fragmento.jpg"
            save_video_extend(video_path)
        else:
            print(f"Error al leer el último frame del video: {video_path}")
    except Exception as e:
        print(f"Excepción al obtener el último frame: {str(e)}")


# Función para mostrar o ocultar el segundo cuadro de imagen
def activar_end_frame(activar):
    return gr.update(visible=activar)


def run_remove_img():

    remove_image()
    #time.sleep(1)
    directory_image_remove = os.environ.get("IMAGE_REMOVE")
    # Devuelve la ruta del video y un mensaje
    return directory_image_remove, "Successful climbing image"

def run_upscaler_img(scale):

    upscale_image(scale)
    #time.sleep(1)
    directory_image_upscaler = os.environ.get("IMAGE_UPSCALER")
    # Devuelve la ruta del video y un mensaje
    return directory_image_upscaler, "Successful climbing image"

def load_text_ration(selected_ration):
    # Mapeo de idiomas a directorios
    aspe_rations = {
        "1:1": "c",
        "16:9": "1344x768",
        "9:16": "768x1344",
        "4:3": "1152x896",
        "3:4": "896x1152",
        "3:2": "1216x832",
        "2:3": "832x1216",
        "8:5": "1216x768",
        "5:8": "768x1216",
        "19:9": "1472x704",
        "9:19": "704x1472",
        "21:9": "1536x640",
        "9:21": "640x1536"
    }
    resolution = aspe_rations.get(selected_ration)

    return resolution

# Función para actualizar los valores de sliders y el campo de texto según el modelo seleccionado
def update_model_settings(selected_model):
    settings = {
        "PicLumen Realistic V2": (4.5, 25, "NSFW, watermark"),
        "PicLumen Anime V2": (7.0, 25, "(nsfw:0.7), (worst quality:1.5), (low quality:1.5), (normal quality:1.5), lowres,watermark, bad anatomy, bad hands, text, error, missing fingers, extra digit, fewer digits, cropped, jpeg artifacts, signature, username, blurry, artist name"),
        "PicLumen Lineart VI": (5.0, 22, "nsfw, lowres, (bad), text, error, fewer, extra, missing, worst quality, jpeg artifacts, low quality, watermark, unfinished, displeasing, oldest, early, chromatic aberration, signature, extra digits, artistic error, username, scan, [abstract]"),
        "Pony Diffusion V6": (5.0, 22, ""),
        "FLUX.1": (5.0, 4, "")
    }

    scale, steps, negative_prompt = settings[selected_model]
    # Devuelve las actualizaciones para los sliders y el cuadro de texto
    return (
        gr.update(value=scale),
        gr.update(value=steps),
        gr.update(value=negative_prompt, visible=selected_model != "FLUX.1")
    )

# Función para mostrar o ocultar el segundo cuadro de imagen
def activar_seed(activar):
    return gr.update(visible=activar)

def toggle_negative_prompt_visibility(selected_model):
    """
    Muestra u oculta el campo negative_prompts según el modelo seleccionado.
    Si el modelo seleccionado es 'FLUX.1', el campo se oculta.
    """
    return gr.update(visible=selected_model != "FLUX.1")

# Función para procesar y guardar la imagen automáticamente en formato JPG
def process_and_save_image1(image):
    jpg_path = "/tmp/img_fragmento.jpg"

    try:
        if image.format != "JPEG":
            image = image.convert("RGB")
        image.save(jpg_path, "JPEG", quality=100)
        if os.path.exists(jpg_path):
            print(f"Imagen guardada correctamente")

            # Obtener las dimensiones de la imagen
            width, height = image.size

            os.environ["WIDTH_IMG_UPSCALER"] = str(width)
            os.environ["HEIGHT_IMG_UPSCALER"] = str(height)
            os.environ["ORIGINAL_IMG_UPSCALER"] = jpg_path
            print(jpg_path)

            # Ejecutar la función
            upload_file_upscaler(jpg_path)

            print(f"Coordenadas guardadas correctamente")

        return None
    except Exception as e:
        print(f"Error al procesar la imagen: {str(e)}")
        return None

# Función para procesar y guardar la imagen automáticamente en formato JPG
def process_and_save_image2(image):
    jpg_path = "/tmp/img_fragmento.jpg"

    try:
        if image.format != "JPEG":
            image = image.convert("RGB")
        image.save(jpg_path, "JPEG", quality=100)
        if os.path.exists(jpg_path):
            print(f"Imagen guardada correctamente")

            # Obtener las dimensiones de la imagen
            width, height = image.size

            os.environ["WIDTH_IMG_REMOVE"] = str(width)
            os.environ["HEIGHT_IMG_REMOVE"] = str(height)
            os.environ["ORIGINAL_IMG_REMOVE"] = jpg_path
            print(jpg_path)

            # Ejecutar la función
            upload_file_remove(jpg_path)

            print(f"Coordenadas guardadas correctamente")

        return None
    except Exception as e:
        print(f"Error al procesar la imagen: {str(e)}")
        return None


def up_save_button_click():
              # Llamar a la función para crear el archivo zip
              zip_file = up_zip_of_images()

              # Devolver el archivo para que el componente gr.File pueda manejarlo
              return zip_file  # El archivo zip será devuelto al componente gr.File para su descarga

            # Función para crear el archivo .zip de la carpeta de imágenes
def up_zip_of_images():
                # Crear el archivo zip
                zip_filename = "/tmp/upscalers_images.zip"
                shutil.make_archive(zip_filename.replace(".zip", ""), 'zip', "/tmp/img_upscaler")  # Comprimir la carpeta

                # Devolver el archivo comprimido para ser descargado
                return zip_filename

def rev_save_button_click():
              # Llamar a la función para crear el archivo zip
              zip_file = rev_zip_of_images()

              # Devolver el archivo para que el componente gr.File pueda manejarlo
              return zip_file  # El archivo zip será devuelto al componente gr.File para su descarga

            # Función para crear el archivo .zip de la carpeta de imágenes
def rev_zip_of_images():
                # Crear el archivo zip
                zip_filename = "/tmp/remove_images.zip"
                shutil.make_archive(zip_filename.replace(".zip", ""), 'zip', "/tmp/img_remove")  # Comprimir la carpeta

                # Devolver el archivo comprimido para ser descargado
                return zip_filename


# Función para crear el archivo .zip de la carpeta de imágenes
def create_zip_of_images():
        # Crear el archivo zip
        zip_filename = "/tmp/generated_images.zip"
        shutil.make_archive(zip_filename.replace(".zip", ""), 'zip', "/tmp/images")  # Comprimir la carpeta

        # Devolver el archivo comprimido para ser descargado
        return zip_filename

    # Función para ejecutar cuando se presiona el botón "Save All"
def on_save_button_click():
        # Llamar a la función para crear el archivo zip
        zip_file = create_zip_of_images()

        # Devolver el archivo para que el componente gr.File pueda manejarlo
        return zip_file  # El archivo zip será devuelto al componente gr.File para su descarga


    # Función para ejecutar cuando se presiona el botón "Generate"
def on_generate_button_click(prompt, batch_size, selected_ration, steps, hires_scale, seed_text, seed_fixed, models_type, negative_prompts):

        token = os.environ.get("TOKEN_PIC")
        if not token:
          configurar_usuario()
          token = os.environ.get("TOKEN_PIC")
          user_id = os.environ.get("USER_ID_PIC")
          print("token:", token)
          print("user_id", user_id)
        if models_type=="FLUX.1":
          negative_prompt = ""
        else:
          negative_prompt = negative_prompts

        if seed_fixed:
           seed = seed_text
        else:
           seed = random.randint(0, 73709551615)

        wid_hei = load_text_ration(selected_ration)

        ancho, alto = map(int, wid_hei.split('x'))

        print(ancho)
        print(alto)

        print(seed)

        width = ancho
        height = alto
        cfg = 7
        denoise = 1
        hires_fix_denoise = 0.6
        img_url = ""
        style = ""


        if models_type=="FLUX.1":
           mark_id, img_paths = generar_imagen_flux(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Realistic V2":
           mark_id, img_paths = generar_imagen_realisticv2(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Anime V2":
           mark_id, img_paths = generar_imagen_animev2(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Lineart VI":
           mark_id, img_paths = generar_imagen_linearv1(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="Pony Diffusion V6":
           mark_id, img_paths = generar_imagen_ponyv6(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        # Rellenar con None hasta llegar a 4 imágenes si es necesario
        while len(img_paths) < 4:
            img_paths.append(None)

        # Crear una lista de actualizaciones para cada imagen basada en el valor del slider
        image_updates = []

        # Hacer visibles las imágenes según el número seleccionado en el slider
        if batch_size >= 1:
            image_updates.append(gr.update(value=img_paths[0], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 2:
            image_updates.append(gr.update(value=img_paths[1], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 3:
            image_updates.append(gr.update(value=img_paths[2], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 4:
            image_updates.append(gr.update(value=img_paths[3], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        # Actualizar el output_textbox con el número de imágenes generadas
        image_updates.append(f"""
        Model: {models_type}\n
        Seed: {seed}\n
        Aspect Ratio: {selected_ration}\n
        Width: {ancho}\n
        Height: {alto}\n
        Steps: {steps}\n
        Guidance Scale: {hires_scale}\n
        Generated {batch_size} images for prompt: {prompt}\n
        Negative Prompt: {negative_prompts}
                             """)

        # Devolver las actualizaciones
        return image_updates
# Función para crear el archivo .zip de la carpeta de imágenes
def create_zip_of_images():
        # Crear el archivo zip
        zip_filename = "/tmp/generated_images.zip"
        shutil.make_archive(zip_filename.replace(".zip", ""), 'zip', "/tmp/images")  # Comprimir la carpeta

        # Devolver el archivo comprimido para ser descargado
        return zip_filename

# Función para ejecutar cuando se presiona el botón "Save All"
def on_save_button_click():
        # Llamar a la función para crear el archivo zip
        zip_file = create_zip_of_images()

        # Devolver el archivo para que el componente gr.File pueda manejarlo
        return zip_file  # El archivo zip será devuelto al componente gr.File para su descarga


# Función para ejecutar cuando se presiona el botón "Generate"
def on_generate_button_click(prompt, batch_size, selected_ration, steps, hires_scale, seed_text, seed_fixed, models_type, negative_prompts):

        token = os.environ.get("TOKEN_PIC")
        if not token:
          configurar_usuario()
          token = os.environ.get("TOKEN_PIC")
          user_id = os.environ.get("USER_ID_PIC")
          print("token:", token)
          print("user_id", user_id)
        if models_type=="FLUX.1":
          negative_prompt = ""
        else:
          negative_prompt = negative_prompts

        if seed_fixed:
           seed = seed_text
        else:
           seed = random.randint(0, 73709551615)

        wid_hei = load_text_ration(selected_ration)

        ancho, alto = map(int, wid_hei.split('x'))

        print(ancho)
        print(alto)

        print(seed)

        width = ancho
        height = alto
        cfg = 7
        denoise = 1
        hires_fix_denoise = 0.6
        img_url = ""
        style = ""


        if models_type=="FLUX.1":
           mark_id, img_paths = generar_imagen_flux(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Realistic V2":
           mark_id, img_paths = generar_imagen_realisticv2(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Anime V2":
           mark_id, img_paths = generar_imagen_animev2(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="PicLumen Lineart VI":
           mark_id, img_paths = generar_imagen_linearv1(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        if models_type=="Pony Diffusion V6":
           mark_id, img_paths = generar_imagen_ponyv6(prompt, negative_prompt, width, height, batch_size, seed, steps, cfg, denoise, hires_fix_denoise, hires_scale, img_url, style)

        # Rellenar con None hasta llegar a 4 imágenes si es necesario
        while len(img_paths) < 4:
            img_paths.append(None)

        # Crear una lista de actualizaciones para cada imagen basada en el valor del slider
        image_updates = []

        # Hacer visibles las imágenes según el número seleccionado en el slider
        if batch_size >= 1:
            image_updates.append(gr.update(value=img_paths[0], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 2:
            image_updates.append(gr.update(value=img_paths[1], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 3:
            image_updates.append(gr.update(value=img_paths[2], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        if batch_size >= 4:
            image_updates.append(gr.update(value=img_paths[3], visible=True))
        else:
            image_updates.append(gr.update(visible=False))

        # Actualizar el output_textbox con el número de imágenes generadas
        image_updates.append(f"""
        Model: {models_type}\n
        Seed: {seed}\n
        Aspect Ratio: {selected_ration}\n
        Width: {ancho}\n
        Height: {alto}\n
        Steps: {steps}\n
        Guidance Scale: {hires_scale}\n
        Generated {batch_size} images for prompt: {prompt}\n
        Negative Prompt: {negative_prompts}
                             """)

        # Devolver las actualizaciones
        return image_updates

# Función para verificar el login y mostrar la interfaz de Gradio
def verify_and_show_data(api_key):
    # Verifica el login
    os.environ["API_KEY"] = api_key

    result, success = login_and_get_data()

    if success:
        # Si el login es exitoso, muestra el contenido de 'data'
        return gr.update(visible=False), gr.update(visible=True), f"Login exitoso. Contenido de 'data': {result}"  # Gradio UI visible
    else:
        # Si el login falla, muestra el mensaje de error
        return gr.update(visible=True), gr.update(visible=False), result  # Solo muestra el login

# Crear la interfaz de Gradio
def gradio_interface():
    with gr.Blocks() as demo:
        with gr.Row(visible=True) as login_row:  # Login visible al principio
            with gr.Column():
                gr.Markdown("<h2 style='text-align: center;'>Login</h2>")
                api_key_input = gr.Textbox(label="API Key", placeholder="Enter your API Key", type="text")
                login_button = gr.Button("Login")
                login_message = gr.Textbox(label="Resultado", interactive=False)

        with gr.Row(visible=False) as gradio_row:  # Esta fila será visible después del login exitoso
            with gr.Column():
              gr.Markdown("<h2 style='text-align: center;'>Curso AI</h2>")
              with gr.Tab("AI Image"):
                  with gr.TabItem("Text to Image"):
                      with gr.Row():
                          with gr.Column(scale=1):

                              models_type = gr.Dropdown(
                                  choices=["PicLumen Realistic V2", "PicLumen Anime V2", "PicLumen Lineart VI", "Pony Diffusion V6", "FLUX.1"],
                                  label="Models",
                                  value="FLUX.1",
                                  elem_id="models_type"
                              )

                              description_input3 = gr.Textbox(label="Prompt", placeholder="Enter text to begin creating a video", elem_id="description_input3")
                              batch_size_slider = gr.Slider(label="Number of Images", minimum=1, maximum=4, step=1, value=4, elem_id="batch_size_slider")

                              step_slider = gr.Slider(label="Steps", minimum=1, maximum=30, step=1, value=4, elem_id="batch_size_slider")

                              scale_slider = gr.Slider(minimum=1.0, maximum=30.0, step=0.1, value=5.0, label="Guidance Scale")

                              aspect_ratio_dropdown = gr.Dropdown(
                                  choices=["1:1", "16:9", "9:16", "4:3", "3:4", "3:2", "2:3", "8:5", "5:8", "19:9", "9:19", "21:9", "9:21"],
                                  label="Aspect Ratio",
                                  value="16:9",
                                  elem_id="aspect_ratio_dropdown"
                              )

                              seed_fixed = gr.Checkbox(label="Seed Manual", value=False, visible=True)

                              seed_text = gr.Textbox(label="Seed", placeholder="Add your seed", value="0", visible=False)

                              negative_prompts = gr.Textbox(label="Negative Prompt", placeholder="Type your negative prompt", elem_id="negative_prompts", visible=False)

                              create_button3 = gr.Button("Generate", elem_id="create_button3")
                              save_button3 = gr.Button("Save All", elem_id="save_button3")  # Botón de guardado

                              # Log para mostrar el enlace de descarga
                              download_log = gr.File(label="Download Zip", elem_id="download_log", interactive=False)  # Usamos gr.File para descargar el archivo comprimido


                          # Videos y botones en el lado derecho
                          with gr.Column(scale=4):  # Ajusta el ancho de la columna de video
                              with gr.Row():  # Primera fila de imágenes
                                  with gr.Column():  # Contenedor para Video 1 y sus botones
                                      video_output1 = gr.Image(label="Image 1", height=250, visible=True)  # Inicialmente invisible
                                  with gr.Column():  # Contenedor para Video 2 y sus botones
                                      video_output2 = gr.Image(label="Image 2", height=250, visible=True)  # Inicialmente invisible

                              with gr.Row():  # Segunda fila de imágenes
                                  with gr.Column():  # Contenedor para Video 3 y sus botones
                                      video_output3 = gr.Image(label="Image 3", height=250, visible=True)  # Inicialmente invisible
                                  with gr.Column():  # Contenedor para Video 4 y sus botones
                                      video_output4 = gr.Image(label="Image 4", height=250, visible=True)  # Inicialmente invisible

                              output_textbox3 = gr.Textbox(label="Output", interactive=False, elem_id="output_textbox3")  # Cambia el nombre del textbox


                      # Conectar la interfaz de usuario con la función de generación de imágenes
                      create_button3.click(
                      on_generate_button_click,
                      inputs=[description_input3, batch_size_slider, aspect_ratio_dropdown, step_slider, scale_slider, seed_text, seed_fixed, models_type, negative_prompts],  # Añadimos el slider como entrada
                      outputs=[video_output1, video_output2, video_output3, video_output4, output_textbox3]
                      )

                      seed_fixed.change(activar_seed, seed_fixed, seed_text)

                      # Conexión entre modelo y configuración dinámica
                      models_type.change(
                              update_model_settings,
                              inputs=[models_type],
                              outputs=[scale_slider, step_slider, negative_prompts]
                          )

                      # Conectar la interfaz de usuario con la función de guardado
                      save_button3.click(on_save_button_click, outputs=download_log)  # Devolver el archivo comprimido a gr.File






                  with gr.TabItem("Flux 1.1 Ultra Pro"):
                        with gr.Row():
                            with gr.Column(scale=1):

                                models_type = gr.Dropdown(
                                    choices=["flux-pro-1.1", "flux-pro-1.1-ultra"],
                                    label="Models",
                                    value="flux-pro-1.1",
                                    elem_id="models_type"
                                )


                                aspect_ratio_dropdown = gr.Dropdown(
                                    choices=["1:1", "16:9", "9:16", "4:3", "3:4"],
                                    label="Aspect Ratio",
                                    value="16:9",
                                    elem_id="aspect_ratio_dropdown"
                                )

                                description_input3 = gr.Textbox(label="Prompt", placeholder="Enter text to begin creating a video", elem_id="description_input3")

                                create_button3 = gr.Button("Generate", elem_id="create_button3")
                                save_button3 = gr.Button("Save All", elem_id="save_button3")  # Botón de guardado

                                # Log para mostrar el enlace de descarga
                                download_log = gr.File(label="Download Zip", elem_id="download_log", interactive=False)  # Usamos gr.File para descargar el archivo comprimido


                            # Videos y botones en el lado derecho
                            with gr.Column(scale=4):  # Ajusta el ancho de la columna de video
                                with gr.Row():  # Primera fila de imágenes
                                    with gr.Column():  # Contenedor para Video 1 y sus botones
                                         video_output1 = gr.Image(label="Image 1", height=250, visible=True)  # Inicialmente invisible
                                    with gr.Column():  # Contenedor para Video 2 y sus botones
                                          video_output2 = gr.Image(label="Image 2", height=250, visible=True)  # Inicialmente invisible
                                output_textbox3 = gr.Textbox(label="Output", interactive=False, elem_id="output_textbox3")  # Cambia el nombre del textbox


                        # Conectar la interfaz de usuario con la función de generación de imágenes
                        create_button3.click(
                        on_generate_fluxpro_click,
                        inputs=[description_input3, aspect_ratio_dropdown, models_type],  # Añadimos el slider como entrada
                        outputs=[video_output1, video_output2, output_textbox3]
                        )

                        # Conectar la interfaz de usuario con la función de guardado
                        save_button3.click(on_save_fluxpro_click, outputs=download_log)  # Devolver el archivo comprimido a gr.File


            
                  

                  with gr.TabItem("Image Upscaler"):
                      with gr.Row():
                          with gr.Column(scale=1):  # Nueva fila y columna con escala
                              # Fila para mostrar ambas imágenes cuando se activa subject, length, loop_video, prompt_upsampling
                              with gr.Row():
                                  # Imagen de inicio (carga de archivo)
                                  img1 = gr.Image(type="pil", label="Drag image here or select image", interactive=True,
                                                  elem_id="img1", width=200, height=200)  # Ajustar tamaño de la imagen


                              upscaler_slider = gr.Slider(label="Upscaler Images", minimum=2, maximum=4, step=2, value=2, elem_id="upscaler_slider")


                              upscaler_button = gr.Button("Upscaler", elem_id="upscaler_button")
                              save_up_button = gr.Button("Save", elem_id="save_button") # Botón de guardado

                              # Log para mostrar el enlace de descarga
                              download_up_log = gr.File(label="Download Zip", elem_id="download_log", interactive=False)  # Usamos gr.File para descargar el archivo comprimidov


                          with gr.Column(scale=3):  # Nueva fila y columna con escala
                              image_upscale_output = gr.Image(label="Image Upscale", elem_id="}image_upscaler")
                              output_textbox = gr.Textbox(label="Output", interactive=False, elem_id="output_textbox") # Cambia el nombre del textbox

                      # Vincular botón al método
                      upscaler_button.click(
                          fn=run_upscaler_img,
                          inputs=[upscaler_slider],
                          outputs=[image_upscale_output, output_textbox]
                      )

                      img1.change(
                          fn=process_and_save_image1,
                          inputs=img1,
                          outputs=[]
                      )

                      save_up_button.click(up_save_button_click, outputs=download_up_log)










                  with gr.TabItem("Remove Background"):
                      with gr.Row():
                          with gr.Column(scale=1):  # Nueva fila y columna con escala
                              # Fila para mostrar ambas imágenes cuando se activa subject, length, loop_video, prompt_upsampling
                              with gr.Row():
                                  # Imagen de inicio (carga de archivo)
                                  img2 = gr.Image(type="pil", label="Drag image here or select image", interactive=True,
                                                  elem_id="img2", width=200, height=200)  # Ajustar tamaño de la imagen

                              remove_button = gr.Button("Remove", elem_id="remove_button")
                              save_rev_button = gr.Button("Save", elem_id="save_button") # Botón de guardado

                              # Log para mostrar el enlace de descarga
                              download_rev_log = gr.File(label="Download Zip", elem_id="download_log", interactive=False)  # Usamos gr.File para descargar el archivo comprimidov


                          with gr.Column(scale=3):  # Nueva fila y columna con escala
                              image_rev_output = gr.Image(label="Image remove", elem_id="image_remove", height=450)
                              output_textbox = gr.Textbox(label="Output", interactive=False, elem_id="output_textbox") # Cambia el nombre del textbox

                      # Vincular botón al método
                      remove_button.click(
                          fn=run_remove_img,
                          inputs=[],
                          outputs=[image_rev_output, output_textbox]
                      )

                      img2.change(
                          fn=process_and_save_image2,
                          inputs=img2,
                          outputs=[]
                      )

                      save_rev_button.click(rev_save_button_click, outputs=download_rev_log)


              with gr.Tab("AI Video Runway Gen3"):
                  with gr.Tab("Image to Video"):
                      with gr.Row():
                          with gr.Column(scale=1):  # Nueva fila y columna con escala
                              add_end_frame = gr.Checkbox(label="Add End Frame", value=False, visible=True)

                              # Fila para mostrar ambas imágenes cuando se activa subject, length, loop_video, prompt_upsampling
                              with gr.Row():
                                  # Imagen de inicio (carga de archivo)
                                  img1 = gr.Image(type="pil", label="Drag image here or select image", interactive=True,
                                                  elem_id="img1", width=200, height=200)  # Ajustar tamaño de la imagen

                                  # Imagen de fin (se oculta inicialmente)
                                  img2 = gr.Image(type="pil", label="Upload the last frame image", interactive=True,
                                                  elem_id="img2", visible=False, width=200, height=200)  # Ajustar tamaño de la imagen

                              subject = gr.Textbox(label="Prompt",
                                                            placeholder="Aquí va una caja de texto editable para el prompt",
                                                            elem_id="description_input")

                              aspect_ratio_dropdown = gr.Dropdown(
                                  choices=["16:9", "9:16", "4:3", "1:1"],
                                  label="Aspect Ratio",
                                  value="16:9",
                                  elem_id="aspect_ratio_dropdown"
                              )

                              loop_video = gr.Checkbox(label="loop video", value=False, visible=False, elem_id="loop_video")

                              prompt_upsampling = gr.Checkbox(label="prompt upsampling", value=True, visible=False, elem_id="prompt_upsampling")

                              length = gr.Dropdown(
                                  choices=["5", "10"],
                                  label="secunds",
                                  value="5",
                                  elem_id="length", visible=False
                              )

                              slider_failed = gr.Slider(minimum=1, maximum=30, step=1, value=15, visible=False, label="Select the maximum waiting minutes")

                              with gr.Row():
                                  create_button = gr.Button("Create", elem_id="create_button")
                                  extend_button = gr.Button("Extend", elem_id="extend_button")

                              with gr.Row():
                                  recreate_button = gr.Button("Re-create", elem_id="recreate_button")  # Nuevo botón "Re-create"
                                  save_button = gr.Button("Save", elem_id="save_button") # Botón de guardado

                          with gr.Column(scale=2):  # Nueva fila y columna con escala
                              video_output = gr.Video(label="Video Output Image to Video", height=400, elem_id="video_output_image_to_video")
                              output_textbox = gr.Textbox(label="Output", interactive=False, elem_id="output_textbox") # Cambia el nombre del textbox



                      # Lógica para mostrar el segundo cuadro de imagen al activar el checkbox
                      add_end_frame.change(activar_end_frame, add_end_frame, img2)

                      # Procesar la imagen automáticamente cuando se carga
                      img1.change(
                          fn=process_upload_image1_runway,
                          inputs=img1,
                          outputs=[]
                      )

                      img2.change(
                          fn=process_upload_image2_runway,
                          inputs=img2,
                          outputs=[]
                      )

                      # Vincular botón al método
                      create_button.click(
                          fn=run_generate_img_video_runway,
                          inputs=[subject, aspect_ratio_dropdown, length, loop_video, prompt_upsampling, add_end_frame, slider_failed],
                          outputs=[video_output, output_textbox]
                      )

                      extend_button.click(
                          fn=run_extend_runway,
                          inputs=[subject, aspect_ratio_dropdown, length, loop_video, prompt_upsampling, slider_failed],
                          outputs=[video_output, output_textbox]
                      )

                      recreate_button.click(
                          fn=run_recreate_img_video_runway,
                          inputs=[subject, aspect_ratio_dropdown, length, loop_video, prompt_upsampling, slider_failed],
                          outputs=[video_output, output_textbox]
                      )


                      # Vincular el botón Save
                      save_button.click(
                          fn=run_save_and_display,
                          inputs=[],
                          outputs=[output_textbox, video_output]
                      )




        # Acción del login
        login_button.click(verify_and_show_data, inputs=[api_key_input], outputs=[login_row, gradio_row, login_message])


    demo.launch(inline=False, debug=True, share=True)

# Llamar a la función para lanzar la interfaz de Gradio
gradio_interface()


#@title subir imagen Minimax
import requests
import uuid
import json
import ast
import os
import time
from kreg import register_user

def subir_media_runway2(path_image):
    bearer_token = os.environ.get("BEARER_TOKEN")
    refresh_token = os.environ.get("REFRESH_TOKEN")
    uuids = str(uuid.uuid4())
    # URL del endpoint
    url = "https://kaiber.ai/api/v1/media/save_media"

    # Cabeceras completas (sin Content-Type explícito)
    headers = {
        "Host": "kaiber.ai",
        "Connection": "keep-alive",
        "X-Platform": "web",
        "Authorization": f"Bearer {bearer_token}",
        "sec-ch-ua-platform": "\"Windows\"",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6ImRhNzUyMmRlYjA3YWY1MWQiLCJ0ciI6IjcwMzJjNTFjNTc2ZjAwYmUxMjhiZWIxYTJlZjliZWIwIiwidGkiOjE3MzI4MjgzNTY1NDN9fQ==",
        "sec-ch-ua-mobile": "?0",
        "baggage": "sentry-environment=production,sentry-release=14ffe6fa8d526ee741281bffeeeaa90c5da55b2c,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=3d91e402e13d43aea3b2c0341a8cb686,sentry-sample_rate=1,sentry-sampled=true",
        "sentry-trace": "3d91e402e13d43aea3b2c0341a8cb686-9dbe92b24c87786d-1",
        "traceparent": "00-db9c7f20e16dcac28406b2cff8b6c737-eade0963ffb1e941-01",
        "X-Refresh-Token": refresh_token,
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "tracestate": "4480399@nr=0-1-4480399-1120323572-eade0963ffb1e941----1732949641749",
        "X-Timezone-Offset": "180",
        "Origin": "https://kaiber.ai",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": f"https://kaiber.ai/superstudio/canvas/{uuids}",
        "Accept-Language": "es-ES,es;q=0.9",
        "Accept-Encoding": "gzip, deflate"
    }

    # Datos del formulario
    files = {
        "media": ("Sin título.png", open(f"{path_image}", "rb"), "image/png"),
    }
    data = {
        "tags": '[{"ns":"Media","name":"Image"},{"ns":"Uploaded","name":"Yes"}]',
        "mediaId": f"{uuids}",
    }



    response = requests.post(url, headers=headers, files=files, data=data)

    if response.status_code == 200:
        # Intentar convertir la respuesta a JSON
        try:
            data_dict = ast.literal_eval(response.text)

            # Extraer valores
            asset_key_id = data_dict['media']['assetKey']
            media_ids = data_dict['media']['mediaId']

            os.environ["ASSET_KEY_ID2"] = asset_key_id
            os.environ["MEDIA_ID_IMG2"] = media_ids
            #return media_ids, asset_key_id   # Retorna el mediaId extraído
        except ValueError:
            print("Error al convertir la respuesta a JSON")
            #return None, None
    else:
        print(f"Error en la solicitud: {response.status_code}")
        register_user()
        time.sleep(2)
        subir_media_runway2(path_image)


import requests
import os
import re
import time
import hashlib
import json
import random
import string

def generar_nombre_completo():
    """Genera un nombre completo triplicando el nombre y apellido, junto con un número aleatorio de 3 dígitos."""
    nombres = ["Juan", "Pedro", "Maria", "Ana", "Luis", "Sofia", "Diego", "Laura", "Javier", "Isabel",
               "Pablo", "Marta", "David", "Elena", "Sergio", "Irene", "Daniel", "Alicia", "Carlos", "Sandra",
               "Antonio", "Lucia", "Miguel", "Sara", "Jose", "Cristina", "Alberto", "Blanca", "Alejandro", "Marta",
               "Francisco", "Esther", "Roberto", "Silvia", "Manuel", "Patricia", "Marcos", "Victoria", "Fernando", "Rosa",
               # Nombres comunes de EE.UU.
               "James", "John", "Robert", "Michael", "William", "David", "Richard", "Joseph", "Charles", "Thomas",
               "Christopher", "Daniel", "Matthew", "Anthony", "Mark", "Donald", "Steven", "Paul", "Andrew", "Joshua",
               "Kenneth", "Kevin", "Brian", "George", "Edward", "Ronald", "Timothy", "Jason", "Jeffrey", "Ryan",
               "Jacob", "Gary", "Nicholas", "Eric", "Jonathan", "Stephen", "Larry", "Justin", "Scott", "Brandon",
               "Benjamin", "Samuel", "Frank", "Gregory", "Raymond", "Alexander", "Patrick", "Jack", "Dennis", "Jerry",
               "Tyler", "Aaron", "Henry", "Douglas", "Jose", "Peter", "Adam", "Zachary", "Nathan", "Walter", 
               "Kyle", "Harold", "Carl", "Arthur", "Gerald", "Roger", "Keith", "Jeremy", "Terry", "Lawrence",
               "Sean", "Christian", "Ethan", "Austin", "Joe", "Jordan", "Albert", "Jesse", "Willie", "Billy"]

    apellidos = ["Garcia", "Rodriguez", "Gonzalez", "Fernandez", "Lopez", "Martinez", "Sanchez", "Perez", "Alonso", "Diaz",
                 "Martin", "Ruiz", "Hernandez", "Jimenez", "Torres", "Moreno", "Gomez", "Romero", "Alvarez", "Vazquez",
                 "Gil", "Lopez", "Ramirez", "Santos", "Castro", "Suarez", "Munoz", "Gomez", "Gonzalez", "Navarro",
                 "Dominguez", "Lopez", "Rodriguez", "Sanchez", "Perez", "Garcia", "Gonzalez", "Martinez", "Fernandez", "Lopez",
                 # Apellidos comunes de EE.UU.
                 "Smith", "Johnson", "Williams", "Brown", "Jones", "Garcia", "Miller", "Davis", "Rodriguez", "Martinez",
                 "Hernandez", "Lopez", "Gonzalez", "Wilson", "Anderson", "Thomas", "Taylor", "Moore", "Jackson", "Martin",
                 "Lee", "Perez", "Thompson", "White", "Harris", "Sanchez", "Clark", "Ramirez", "Lewis", "Robinson",
                 "Walker", "Young", "Allen", "King", "Wright", "Scott", "Torres", "Nguyen", "Hill", "Flores",
                 "Green", "Adams", "Nelson", "Baker", "Hall", "Rivera", "Campbell", "Mitchell", "Carter", "Roberts",
                 "Gomez", "Phillips", "Evans", "Turner", "Diaz", "Parker", "Cruz", "Edwards", "Collins", "Reyes",
                 "Stewart", "Morris", "Morales", "Murphy", "Cook", "Rogers", "Gutierrez", "Ortiz", "Morgan", "Cooper",
                 "Peterson", "Bailey", "Reed", "Kelly", "Howard", "Ward", "Cox", "Diaz", "Richardson", "Wood"]


    nombre = random.choice(nombres)
    apellido = random.choice(apellidos)
    numero = random.randint(100000, 999999)

    nombre_completo = f"{nombre}_{apellido}_{numero}"
    return nombre_completo

def generar_contrasena():
    """Genera una contraseña aleatoria."""
    caracteres = string.ascii_letters + "0123456789" + "#$%&/()@_-*+[]"
    longitud = 10
    contraseña = ''.join(random.choice(caracteres) for _ in range(longitud))
    return contraseña

def enviar_formulario():
    url = 'https://email-fake.com/'

    datos = {'campo_correo': 'ejemplo@dominio.com'}

    """Envía una solicitud POST a un formulario web."""
    response = requests.post(url, data=datos)
    return response.text

def extraer_dominios(response_text):
    """Extrae dominios de un texto utilizando expresiones regulares."""
    dominios = re.findall(r'id="([^"]+\.[^"]+)"', response_text)
    return dominios

def obtener_sitio_web_aleatorio(response_text):
    """Obtiene un sitio web aleatorio de los dominios extraídos."""
    dominios = extraer_dominios(response_text)
    sitio_web_aleatorio = random.choice(dominios)
    return sitio_web_aleatorio




def iniciar_sesion(account, password):
    url = "https://piclumen.com/api/user/login"

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": "",  # Agrega tu token aquí si es necesario
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryG0HDGc4eqwD1nY07",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/account",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    # Generar el hash MD5 de la contraseña
    #hashed_password = hashlib.md5(password.encode('utf-8')).hexdigest()

    # Cuerpo de la solicitud con la estructura exacta requerida
    payload = (
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07\r\n"
        f"Content-Disposition: form-data; name=\"account\"\r\n\r\n"
        f"{account}\r\n"
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07\r\n"
        f"Content-Disposition: form-data; name=\"password\"\r\n\r\n"
        f"{password}\r\n"
        "------WebKitFormBoundaryG0HDGc4eqwD1nY07--\r\n"
    )

    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, data=payload)
    print(response.text)

    # Manejar la respuesta
    if response.ok:
        respuesta_json = response.json()
        if "data" in respuesta_json:
            # Extraer token y userId
            tokens = respuesta_json["data"].get("token", None)
            os.environ["TOKEN_PIC"] = tokens
            user_ids = respuesta_json["data"].get("userId", None)
            os.environ["USER_ID_PIC"] = user_ids
            return tokens, user_ids
        else:
            return None, None
    else:
        return None, None


def registrar_usuario(account, password, validate_code):
    url = "https://piclumen.com/api/user/register"

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": "",  # Agrega tu token aquí si es necesario
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "application/json;charset=UTF-8",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/account",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate"
    }

    # Generar el hash MD5 para la contraseña
    #hashed_password = hashlib.md5(password.encode('utf-8')).hexdigest()

    # Cuerpo de la solicitud
    payload = {
        "account": account,
        "password": password,
        "validateCode": validate_code
    }

    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, json=payload)

    # Manejar la respuesta
    print(response.headers)
    print(response.json())

    if 'success' in response.text:
        print("La palabra 'success' está presente en el mensaje.")

        token, user_id = iniciar_sesion(account, password)

        return token, user_id

    elif 'deleted' in response.text:
        print("La palabra 'deleted' está presente en el mensaje.")
     
        return None,  None
    else:
        print("Ni 'success' ni 'deleted' están presentes en el mensaje.")
        return None,  None
    
    #status  = print_email_message(response.text)
    return None,  None


COMMON_HEADERS = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36',
    'Accept-Language': 'es-ES,es;q=0.9',
    'Accept-Encoding': 'gzip, deflate'
}

def extract_verification_code(html_content):
    """
    Extrae el código de verificación de un contenido HTML dado.
    
    Args:
        html_content (str): El texto HTML que contiene el código de verificación.
    
    Returns:
        str: El código de verificación como una cadena, o None si no se encuentra.
    """
    pattern = r"Your verification code is ：(\d+)"
    match = re.search(pattern, html_content)
    if match:
        return match.group(1)  # Retorna solo el número
    return None  # Retorna None si no encuentra el código

def delete_temp_mail(username_email, dominios_dropdown, extracted_string):
    """Borra el correo temporal especificado."""
    EMAIL_FAKE_URL = 'https://email-fake.com/'
    url = f"{EMAIL_FAKE_URL}/del_mail.php"

    headers = {
        'Host': 'email-fake.com',
        'Connection': 'keep-alive',
        'sec-ch-ua': '"Not_A Brand";v="8", "Chromium";v="120", "Google Chrome";v="120"',
        'Accept': '*/*',
        'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
        'X-Requested-With': 'XMLHttpRequest',
        'sec-ch-ua-mobile': '?0',
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36',
        'sec-ch-ua-platform': '"Windows"',
        'Origin': 'https://email-fake.com',
        'Sec-Fetch-Site': 'same-origin',
        'Sec-Fetch-Mode': 'cors',
        'Sec-Fetch-Dest': 'empty',
        'Accept-Language': 'es-ES,es;q=0.9',
        'Cookie': f'embx=%5B%22{username_email}%40{dominios_dropdown}%22%2C',
    }

    data = f'delll={extracted_string}'

    response = requests.post(url, headers=headers, data=data)

    if "Message deleted successfully" in response.text:
        print("Temporary mail deleted...")
        return True
    else:
        print("Error deleting temporary email...")
        return False

def get_verification_code(username_email, dominios_dropdown):
    """Obtiene el código de verificación del correo y el identificador."""
    EMAIL_FAKE_URL = 'https://email-fake.com/'
    url = f"{EMAIL_FAKE_URL}/"

    headers = {
        'Host': 'email-fake.com',
        'Connection': 'keep-alive',
        'Upgrade-Insecure-Requests': '1',
        **COMMON_HEADERS,
        'Sec-Fetch-Site': 'none',
        'Sec-Fetch-Mode': 'navigate',
        'Sec-Fetch-User': '?1',
        'Sec-Fetch-Dest': 'document',
        'sec-ch-ua': '"Not_A Brand";v="8", "Chromium";v="120", "Google Chrome";v="120"',
        'sec-ch-ua-mobile': '?0',
        'sec-ch-ua-platform': 'Windows',
        'Cookie': f'surl={dominios_dropdown}%2F{username_email}',
    }

    response = requests.get(url, headers=headers)

    verification_code = extract_verification_code(response.text)
    
    # Utiliza una expresión regular para encontrar el identificador largo
    identifier_match = re.search(r'delll:\s*"([a-zA-Z0-9]+)"', response.text)
    #return identifier_match, verification_code

    # Extrae y retorna los valores si fueron encontrados
    if identifier_match:
        identifier = identifier_match.group(1)
        return verification_code, identifier
    else:
        return None, None, None 

import time

def enviar_codigo_registro():
    correo = os.environ.get("USER_EMAIL_PIC")
    password = os.environ.get("PASS_WORD_PIC")
    print(correo)
    print(password)

    name, domain = correo.split('@')

    url = "https://piclumen.com/api/user/register-send-code"

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": "",  # Agrega tu token aquí si es necesario
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryPiHCBk7u93JxSMB2",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/account",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    # Formato exacto del cuerpo de la solicitud con correo como variable
    payload = (
        f"------WebKitFormBoundaryPiHCBk7u93JxSMB2\r\n"
        f"Content-Disposition: form-data; name=\"account\"\r\n\r\n"
        f"{correo}\r\n"
        f"------WebKitFormBoundaryPiHCBk7u93JxSMB2--\r\n"
    )

    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, data=payload)
    print(response.text)
    if 'success' in response.text:
        print("Solicitud enviada con éxito. Buscando código de verificación...")
        
        attempts = 0
        verification_code, identifier = None, None
        
        # Reintentar hasta 6 veces
        while attempts < 6:
            verification_code, identifier = get_verification_code(name, domain)
            if verification_code:  # Si se obtiene el código, salir del bucle
                break
            attempts += 1
            time.sleep(3)  # Esperar 3 segundos antes del siguiente intento

        if verification_code:
            print("Código de verificación obtenido:", verification_code)
            print("Identificador:", identifier)

            # Borrar el correo temporal asociado al identifier
            delete_temp_mail(name, domain, identifier)

            time.sleep(1)
            print("CORREEO", correo)
            print("PASS", password)
            print("CODE", verification_code)
            # Registrar el usuario con el código de verificación
            token, user_id = registrar_usuario(correo, password, verification_code)

            return token, user_id

    print("No se pudo obtener el código de verificación después de 6 intentos.")
    return None, None


def configurar_usuario():
    # Generar el nombre de usuario
    user_name = generar_nombre_completo()
    
    # Obtener el dominio de usuario
    domain_user = obtener_sitio_web_aleatorio(enviar_formulario())
    
    # Crear el correo electrónico del usuario
    user_emails = f"{user_name}@{domain_user}"
    
    # Contraseña (puede venir de otro lugar si es necesario)
    passwords = "c3b974a9b96984fabe65b5ee44a6a6cc" 
    
    # Configurar las variables de entorno
    os.environ["USER_EMAIL_PIC"] = user_emails
    os.environ["PASS_WORD_PIC"] = passwords
    
    # Enviar código de registro
    tokens, user_ids = enviar_codigo_registro()
    
    # Validar los resultados y configurar más variables de entorno
    if tokens and user_ids:
        os.environ["USER_ID_PIC"] = user_ids
        os.environ["TOKEN_PIC"] = tokens
    else:
        print("Error: No se obtuvieron valores válidos para el token o el user_id.")
        configurar_usuario()


import requests
import os
import time
from IPython.display import Image, display

def eliminar_imagen(correo, prompt_id, img_name):
    token = os.environ.get("TOKEN_PIC")
    url = "https://piclumen.com/api/img/delete"

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": token,  # Incluir el token aquí
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryNYpFkpGlmkQKklUK",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/image-generator/create",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    # El cuerpo de la solicitud es un multipart/form-data
    data = (
        f'------WebKitFormBoundaryNYpFkpGlmkQKklUK\r\n'
        f'Content-Disposition: form-data; name="promptId"\r\n\r\n{prompt_id}\r\n'
        f'------WebKitFormBoundaryNYpFkpGlmkQKklUK\r\n'
        f'Content-Disposition: form-data; name="imgName"\r\n\r\n{img_name}\r\n'
        f'------WebKitFormBoundaryNYpFkpGlmkQKklUK\r\n'
        f'Content-Disposition: form-data; name="loginName"\r\n\r\n{correo}\r\n'
        f'------WebKitFormBoundaryNYpFkpGlmkQKklUK--\r\n'
    )

    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, data=data)

    # Manejar la respuesta
    if response.ok:
        return response.json()  # Devuelve la respuesta como JSON
    else:
        return {"error": f"Error en la solicitud: {response.status_code}", "details": response.text}

def procesar_tarea(mark_id):
    attempt_count = 0  # Variable para contar los intentos
    token = os.environ.get("TOKEN_PIC")
    correo = os.environ.get("USER_EMAIL_PIC")
    url = "https://piclumen.com/api/task/processTask"

    img_paths = []  # Lista para almacenar los paths de las imágenes

    headers = {
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": token,  # Incluir el token aquí
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundaryY6Cs6Ri21EvS8cpC",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/image-generator/create",
        "Accept-Language": "es-ES,es;q=0.9,en;q=0.8",
        "Accept-Encoding": "gzip, deflate",
    }

    payload = (
        "------WebKitFormBoundaryY6Cs6Ri21EvS8cpC\r\n"
        f"Content-Disposition: form-data; name=\"markId\"\r\n\r\n"
        f"{mark_id}\r\n"
        "------WebKitFormBoundaryY6Cs6Ri21EvS8cpC--\r\n"
    )

    while True:
        response = requests.post(url, headers=headers, data=payload)

        if response.ok:
            data = response.json()

            if "data" in data and "promptId" in data["data"]:
                prompt_id = data["data"]["promptId"]
                img_urls = data["data"]["img_urls"]

                if img_urls:
                    img_folder = "./images"
                    if not os.path.exists(img_folder):
                        os.makedirs(img_folder)

                    for img_data in img_urls:
                        img_name = img_data["imgName"]
                        img_url = img_data["imgUrl"]

                        # Descargar y guardar la imagen
                        img_response = requests.get(img_url)
                        if img_response.status_code == 200:
                            img_path = os.path.join(img_folder, os.path.basename(img_name))
                            with open(img_path, "wb") as img_file:
                                img_file.write(img_response.content)

                            # Agregar img_path a la lista
                            img_paths.append(img_path)

                            # Eliminar la imagen del servidor
                            eliminar_imagen(correo, prompt_id, img_name)
                        else:
                            print(f"Error al descargar la imagen: {img_url}")

                    # Retornar solo los paths de las imágenes
                    return img_paths
                else:
                    attempt_count += 1
                    print(f"\rIntento {attempt_count}: Esperando 5 segundos antes de intentar nuevamente...", end="")
                    time.sleep(5)
            else:
                print("La tarea aún no está completa, reintentando en 5 segundos...")
                time.sleep(5)
        else:
            print(f"Error en la solicitud: {response.status_code}")
            return []



def generar_imagen_ponyv6(
    prompt,
    negative_prompt="",
    width=1472,
    height=704,
    batch_size=1,
    seed=70212802643,
    steps=4,
    cfg=5,
    denoise=1,
    hires_fix_denoise=0.5,
    hires_scale=2,
    img_url="",
    style=""
):

    token = os.environ.get("TOKEN_PIC")
    url = "https://piclumen.com/api/gen/create"

    headers = {
        "Host": "piclumen.com",
        "Connection": "keep-alive",
        "sec-ch-ua-platform": "\"Windows\"",
        "Authorization": token,
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "Content-Type": "application/json;charset=UTF-8",
        "sec-ch-ua-mobile": "?0",
        "Origin": "https://piclumen.com",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://piclumen.com/app/image-generator/create",
        "Accept-Language": "es-ES,es;q=0.9",
        "Accept-Encoding": "gzip, deflate",
    }

    # Cuerpo de la solicitud JSON con parámetros editables
    payload = {
        "model_id": "14a399de-69d9-4e3b-961d-e95b35853557",  # Modelo fijo
        "prompt": prompt,
        "negative_prompt": negative_prompt,
        "resolution": {
            "width": width,
            "height": height,
            "batch_size": batch_size  # Puedes ajustar si necesario
        },
        "model_ability": {
            "anime_style_control": None  # Valor fijo
        },
        "seed": seed,
        "steps": steps,
        "cfg": cfg,
        "sampler_name": "euler_ancestral",  # Valor fijo
        "scheduler": "karras",             # Valor fijo
        "ponyTags": {},                    # Valor fijo
        "denoise": denoise,
        "hires_fix_denoise": hires_fix_denoise,
        "hires_scale": hires_scale,
        "gen_mode": "quality",             # Valor fijo
        "img2img_info": {
            "img_url": img_url,
            "style": style,
            "weight": 0  # Valor fijo
        }
    }


    # Realizar la solicitud POST
    response = requests.post(url, headers=headers, json=payload)


    #print(response.text)

    # Manejar la respuesta
    if response.ok:
        # Extraer el markId de la respuesta
        response_data = response.json()

        mark_id = response_data.get('data', {}).get('markId', None)  # Extraer markId

        if mark_id:
           #resultado = procesar_tarea(mark_id)
           img_paths = procesar_tarea(mark_id)

        return mark_id, img_paths  # Devuelve el markId extraído
    else:
        return {"error": f"Error en la solicitud: {response.status_code}", "details": response.text}, None


#@title MINIMAX IMAGE A VIDEOO
import requests
import uuid
import json
import os
import requests
from kreg import register_user
from logs import *
import requests
import time
import os
import requests
import time
import os

def delete_account():
    result, success = login_and_get_data()

    if success:

        bearer_token = os.environ.get("BEARER_TOKEN")
        refresh_token = os.environ.get("REFRESH_TOKEN")
        current_password = os.environ.get("NAME_PASS")

        # Cabeceras (headers) de la solicitud
        headers = {
            "Connection": "keep-alive",
            "X-Platform": "web",
            "Authorization": f"Bearer {bearer_token}",  # Token Bearer editable
            "sec-ch-ua-platform": "\"Windows\"",
            "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
            "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6ImZmYTEzMjQ5OGUxNzZhMzciLCJ0ciI6IjQ0NWNkYWI4OGU1YzFjYjhhODlmZWJiMDkyOTdmNTliIiwidGkiOjE3MzI3NzY5NjQ0NDV9fQ==",
            "sec-ch-ua-mobile": "?0",
            "baggage": "sentry-environment=production,sentry-release=e5967f3de92606cfa5faed6b27e5711320af8389,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=71ee1caca0d843a991b316008899b374,sentry-sample_rate=1,sentry-sampled=true",
            "sentry-trace": "71ee1caca0d843a991b316008899b374-a4d6f7a682131ea9-1",
            "traceparent": "00-445cdab88e5c1cb8a89febb09297f59b-ffa132498e176a37-01",
            "X-Refresh-Token": refresh_token,  # Token de refresco editable
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
            "Accept": "application/json, text/plain, */*",
            "Content-Type": "application/json",
            "tracestate": "4480399@nr=0-1-4480399-1120323572-ffa132498e176a37----1732776964445",
            "X-Timezone-Offset": "180",
            "Origin": result[1],
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Referer": result[2],
            "Accept-Language": "es-ES,es;q=0.9",
            "Accept-Encoding": "gzip, deflate",
        }

        # Datos que se envían en el cuerpo de la solicitud
        data = {
            "currentPassword": current_password
        }

        # Realizando la solicitud POST
        response = requests.post(result[0], headers=headers, json=data)

        # Verificando la respuesta
        if response.status_code == 200:
            # Si la respuesta es exitosa, retorna el mensaje
            print(response.json().get("message", "No message in response"))
        else:
            # Si no es exitosa, muestra el error
            print(f"Error {response.status_code}: {response.text}")

def get_media(bearer_token, refresh_token, media_id):
    # URL del endpoint con el ID de media
    url = f"https://kaiber.ai/api/v1/media/{media_id}"

    # Cabeceras (headers) de la solicitud
    headers = {
        "Connection": "keep-alive",
        "X-Platform": "web",
        "Authorization": f"Bearer {bearer_token}",  # Token Bearer editable
        "sec-ch-ua-platform": "\"Windows\"",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6IjQ0NzU5OTUwMTgwYjc3MTgiLCJ0ciI6IjY1NDhiZDU3ZTIyMmNhYzQxMDEwYjRhMTllZjUxZjU2IiwidGkiOjE3MzI3NzA4MzY0MzV9fQ==",
        "sec-ch-ua-mobile": "?0",
        "baggage": "sentry-environment=production,sentry-release=e5967f3de92606cfa5faed6b27e5711320af8389,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=79be22464b9f4e7ba5ea6defd88f9513,sentry-sample_rate=1,sentry-sampled=true",
        "sentry-trace": "6dd3ff7522a14ce6a3bf32473e21d6ce-8745aedda8590f03-1",
        "traceparent": "00-6548bd57e222cac41010b4a19ef51f56-44759950180b7718-01",
        "X-Refresh-Token": refresh_token,  # Token de refresco editable
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "tracestate": "4480399@nr=0-1-4480399-1120323572-44759950180b7718----1732770836435",
        "X-Timezone-Offset": "180",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": f"https://kaiber.ai/superstudio/canvas/{media_id}",  # Referer con el ID de media
        "Accept-Language": "es-ES,es;q=0.9",
        "Accept-Encoding": "gzip, deflate"
    }

    # Realizando la solicitud GET
    response = requests.get(url, headers=headers)

    # Verificando el estado de la respuesta
    if response.status_code == 200:
        return response.json()  # Retornar la respuesta en formato JSON si la solicitud fue exitosa
    else:
        return None  # Si hay error, retornar None para que sigamos esperando

def download_video(url, save_path):
    # Realizar la solicitud para obtener el archivo del video
    response = requests.get(url, stream=True)

    # Verificar si la solicitud fue exitosa
    if response.status_code == 200:
        # Crear el directorio si no existe
        os.makedirs(os.path.dirname(save_path), exist_ok=True)

        # Guardar el archivo en el directorio especificado
        with open(save_path, 'wb') as f:
            for chunk in response.iter_content(chunk_size=1024):
                if chunk:
                    f.write(chunk)
        print(f"\nVideo descargado en: {save_path}")
    else:
        print(f"\nError al descargar el video: {response.status_code}")

def monitor_media(bearer_token, refresh_token, media_id):
    attempt_count = 0  # Contador de intentos

    while True:
        # Llamar a la función get_media para obtener la información del video
        response_data = get_media(bearer_token, refresh_token, media_id)

        if response_data:
            media_status = response_data.get("media", {}).get("status")
            
            # Verificar si el estado es "failed"
            if media_status == "failed":
                os.environ["FAILDE_VIDEO"] = media_status
                print("\nEl procesamiento del video ha fallado. Proceso detenido.")
                break

            # Verificar si el estado es "pending"
            elif media_status == "pending":
                os.environ["FAILDE_VIDEO"] = media_status
                attempt_count += 1
                print(f"\rIntento {attempt_count}: Estado pendiente. Esperando 3 segundos antes de intentar nuevamente...", end="")
                time.sleep(3)

            # Verificar si la respuesta contiene la clave "source" para descargar el video
            elif "source" in response_data.get("media", {}):
                video_url = response_data["media"]["source"]

                # Ruta donde se guardará el video
                save_path = f"/content/video/{media_id}.mp4"

                # Descargar el video
                download_video(video_url, save_path)

                os.environ["DIR_VIDEO"] = save_path
                print("\nVideo descargado exitosamente. Proceso completado.")
                break
        else:
            print("\nNo se pudo obtener la información del video. Intentando nuevamente...")

        # Aumentar el contador de intentos y esperar
        attempt_count += 1
        time.sleep(3)

def gen_runway_image2_to_video(model_type="RunwayVideoGen3", elements_0="subject", elements_1="runwayStartKeyframe", elements_2="runwayEndKeyframe", elements_3="runwayVideoGen3Settings", aspect_ratio="16:9", width=1344, height=768, subject="talking youtuber", evolve=4, version=1, video_type="Video", motion_magnitude=4, length=5, stable_diffusion_checkpoint="dreamshaper", guidance=3, steps=38, denoise=0.4, creativity_scale=5, loop_video=False, audio_reactivity=6, scale_factor=2, topaz_model="Standard V2", topaz_face_enhancement_creativity=0, flux_pro_model="flux-pro-1.1-ultra", prompt_upsampling=True, form_index=1, starting_frame_weights="", runway_EndKeyframeWeights="0.8", name="Runway Video", userProvidedStartingFrame="", runway_EndKeyframe=""):
    result, success = login_and_get_data()

    if success:

        bearer_token = os.environ.get("BEARER_TOKEN")
        refresh_token = os.environ.get("REFRESH_TOKEN")
        uuids = str(uuid.uuid4())

        headers = {
            "Host": "kaiber.ai",
            "Connection": "keep-alive",
            "X-Platform": "web",
            "Authorization": f"Bearer {bearer_token}",
            "sec-ch-ua-platform": "\"Windows\"",
            "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
            "sec-ch-ua-mobile": "?0",
            "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6IjczY2I2MzFkZWQ3N2RiYmQiLCJ0ciI6ImJlNDZjZGM5ZGY5YTRmM2M3ODBkYjRlMDczZjA4OTNiIiwidGkiOjE3MzMwMDk5MTUwNjV9fQ==",
            "baggage": "sentry-environment=production,sentry-release=3efe4968f941933ebe2c9920e9a021f8740a50bf,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=13801de87c0547ab91fcf9d38f49316d,sentry-sample_rate=1,sentry-sampled=true",
            "sentry-trace": "13801de87c0547ab91fcf9d38f49316d-9b93cf813adb3f97-1",
            "traceparent": "00-be46cdc9df9a4f3c780db4e073f0893b-73cb631ded77dbbd-01",
            "X-Refresh-Token": "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiI2NzRiOTg4MGIwN2YxZTliNWU3NDlhMDYiLCJzaWQiOiI2NzRiOThiYzNkZDNiMzUwMTQ1ZWNmNmEiLCJpYXQiOjE3MzMwMDc1NTEsImV4cCI6MTc0MDc4MzU1MX0.jCJUko3-Hm_FREinCcoC5TcftZP3qnYjOUaDhukn25E",
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
            "Accept": "application/json, text/plain, */*",
            "tracestate": "4480399@nr=0-1-4480399-1120323572-73cb631ded77dbbd----1733009915065",
            "X-Timezone-Offset": "180",
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Referer": f"{result[6]}{uuids}",
            "Accept-Language": "es-ES,es;q=0.9",
            "Accept-Encoding": "gzip, deflate"
        }

        # Realizar la solicitud GET
        response = requests.get(result[5], headers=headers)
        
        # Comprobar si la solicitud fue exitosa
        if response.status_code == 200:
            data = response.json()  # Analizar la respuesta JSON

            credits = data.get("credits")  # Extraer el valor de 'credits'

                
            # Validar si los créditos son mayores a 25
            if credits >= 25:
                print(f"Credits válidos: {credits} (mayores a 25)")
                process_media(bearer_token, refresh_token, model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, runway_EndKeyframeWeights, name, userProvidedStartingFrame, runway_EndKeyframe)
                
                media_id = os.environ.get("MEDIA_ID")
                
                if media_id:
                  # Llamar a la función que monitoriza la media
                  monitor_media(bearer_token, refresh_token, media_id)
                  
            else:
                print(f"Credits insuficientes: {credits} (deben ser mayores a 25)")
                delete_account()
                time.sleep(1)
                register_user()
                user_email = os.environ.get("NAME_EMAIL")
                user_pass = os.environ.get("NAME_PASS")

                bearer_token = os.environ.get("BEARER_TOKEN")
                refresh_token = os.environ.get("REFRESH_TOKEN")


                print("NAME_EMAIL", user_email)
                print("NAME_PASS", user_pass)

                print("BEARER_TOKEN", bearer_token)
                print("REFRESH_TOKEN", refresh_token)
                time.sleep(2)
                process_media(bearer_token, refresh_token, model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, runway_EndKeyframeWeights, name, userProvidedStartingFrame, runway_EndKeyframe)
                
                media_id = os.environ.get("MEDIA_ID")
                
                if media_id:
                  # Llamar a la función que monitoriza la media
                  monitor_media(bearer_token, refresh_token, media_id)
                
        else:
            print(f"Error: {response.status_code}")
            delete_account()
            time.sleep(1)
            register_user()
            user_email = os.environ.get("NAME_EMAIL")
            user_pass = os.environ.get("NAME_PASS")

            bearer_token = os.environ.get("BEARER_TOKEN")
            refresh_token = os.environ.get("REFRESH_TOKEN")


            print("NAME_EMAIL", user_email)
            print("NAME_PASS", user_pass)

            print("BEARER_TOKEN", bearer_token)
            print("REFRESH_TOKEN", refresh_token)
            time.sleep(2)
            process_media(bearer_token, refresh_token, model_type, elements_0, elements_1, elements_2, elements_3, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, runway_EndKeyframeWeights, name, userProvidedStartingFrame, runway_EndKeyframe)
                
            media_id = os.environ.get("MEDIA_ID")
                
            if media_id:
                # Llamar a la función que monitoriza la media
                monitor_media(bearer_token, refresh_token, media_id)
            

def obtener_media_id(json_data):
    # Convertir el string JSON en un diccionario de Python
    data = json.loads(json_data)

    # Extraer y devolver el mediaId
    return data['medias'][0]['mediaId']

def process_media(bearer_token, refresh_token, model_type="RunwayVideoGen3", elements_0="subject", elements_1="runwayStartKeyframe", elements_2="runwayEndKeyframe", elements_3="runwayVideoGen3Settings", aspect_ratio="16:9", width=1344, height=768, subject="talking youtuber", evolve=4, version=1, video_type="Video", motion_magnitude=4, length=5, stable_diffusion_checkpoint="dreamshaper", guidance=3, steps=38, denoise=0.4, creativity_scale=5, loop_video=False, audio_reactivity=6, scale_factor=2, topaz_model="Standard V2", topaz_face_enhancement_creativity=0, flux_pro_model="flux-pro-1.1-ultra", prompt_upsampling=True, form_index=1, starting_frame_weights="", runway_EndKeyframeWeights="0.8", name="Runway Video", userProvidedStartingFrame="", runway_EndKeyframe=""):
    result, success = login_and_get_data()

    if success:
        
        uuids = str(uuid.uuid4())

        # Headers (cabeceras de la solicitud)
        headers = {
            "Connection": "keep-alive",
            "X-Platform": "web",
            "Authorization": f"Bearer {bearer_token}",  # Bearer token
            "sec-ch-ua-platform": "\"Windows\"",
            "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
            "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6ImUwNmVlYmMxZmE2ODk5ZTciLCJ0ciI6IjRlMWQyMTdmNDA4ZTQyNTc3YmY5YjZmOWY3YzBiN2JhIiwidGkiOjE3MzI3NzA4MzAzODJ9fQ==",
            "sec-ch-ua-mobile": "?0",
            "baggage": "sentry-environment=production,sentry-release=14ffe6fa8d526ee741281bffeeeaa90c5da55b2c,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=3d91e402e13d43aea3b2c0341a8cb686,sentry-sample_rate=1,sentry-sampled=true",
            "sentry-trace": "3d91e402e13d43aea3b2c0341a8cb686-9dbe92b24c87786d-1",
            "traceparent": "00-a9a154c53d69b0507c749da774680fe8-a70a942b8b8286d7-01",
            "X-Refresh-Token": refresh_token,
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
            "Accept": "application/json, text/plain, */*",
            "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundarySGpGyngeeNNpUANH",
            "tracestate": "4480399@nr=0-1-4480399-1120323572-a70a942b8b8286d7----1732949651840",
            "X-Timezone-Offset": "180",
            "Origin": result[8],
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Referer": f"{result[9]}{uuids}",
            "Accept-Language": "es-ES,es;q=0.9",
            "Accept-Encoding": "gzip, deflate",
        }

        # Cuerpo de la solicitud (en formato multipart/form-data)
        data = (
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"mediaIds[]\"\r\n\r\n{uuids}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[modelType]\"\r\n\r\n{model_type}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[elements][0]\"\r\n\r\n{elements_0}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[elements][1]\"\r\n\r\n{elements_1}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][aspectRatio]\"\r\n\r\n{aspect_ratio}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][lockAspectRatio]\"\r\n\r\ntrue\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][width]\"\r\n\r\n{width}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][height]\"\r\n\r\n{height}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][subject]\"\r\n\r\n{subject}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][style]\"\r\n\r\n\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][evolve]\"\r\n\r\n{evolve}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][version]\"\r\n\r\n{version}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][type]\"\r\n\r\n{video_type}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][motionMagnitude]\"\r\n\r\n{motion_magnitude}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][length]\"\r\n\r\n{length}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][stableDiffusionCheckpoint]\"\r\n\r\n{stable_diffusion_checkpoint}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][guidance]\"\r\n\r\n{guidance}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][steps]\"\r\n\r\n{steps}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][denoise]\"\r\n\r\n{denoise}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][creativityScale]\"\r\n\r\n{creativity_scale}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][loopVideo]\"\r\n\r\n{str(loop_video).lower()}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][audioReactivity]\"\r\n\r\n{audio_reactivity}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][scaleFactor]\"\r\n\r\n{scale_factor}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][topazModel]\"\r\n\r\n{topaz_model}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][topazFaceEnhancementCreativity]\"\r\n\r\n{topaz_face_enhancement_creativity}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][fluxProModel]\"\r\n\r\n{flux_pro_model}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][promptUpsampling]\"\r\n\r\n{str(prompt_upsampling).lower()}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][userProvidedStartingFrame][0]\"\r\n\r\n{userProvidedStartingFrame}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][runwayEndKeyframe][0]\"\r\n\r\n{runway_EndKeyframe}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][formIndex]\"\r\n\r\n{form_index}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][runwayEndKeyframeWeights][0]\"\r\n\r\n{runway_EndKeyframeWeights}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[formValues][userProvidedStartingFrameWeights][0]\"\r\n\r\n{starting_frame_weights}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH\r\n"
            f"Content-Disposition: form-data; name=\"flow[name]\"\r\n\r\n{name}\r\n"
            f"------WebKitFormBoundarySGpGyngeeNNpUANH--\r\n"
        )

        # Realizando la solicitud POST
        response = requests.post(result[7], headers=headers, data=data)

        #print(response.text)

        # Si la respuesta es exitosa (código 200)
        if response.status_code == 200:
            # Intentar convertir la respuesta a JSON
            try:
                data = json.loads(response.text)

                # Extraer y devolver el mediaId
                media_id = data['medias'][0]['mediaId']
                os.environ["MEDIA_ID"] = media_id
                print(media_id)
                #return media_id  # Retorna el mediaId extraído
            except ValueError:
                print("Error al convertir la respuesta a JSON")
                os.environ["MEDIA_ID"] = None
                #return None
        else:
            print(f"Error en la solicitud: {response.status_code}")
            os.environ["MEDIA_ID"] = None
            #return None


#@title flux ultra
import requests
import uuid
import json
from kreg import register_user
import time
import os

def delete_account():
    bearer_token = os.environ.get("BEARER_TOKEN")
    refresh_token = os.environ.get("REFRESH_TOKEN")
    current_password = os.environ.get("NAME_PASS")
    # URL del endpoint para eliminar la cuenta
    url = "https://kaiber.ai/api/auth/myaccount/delete"

    # Cabeceras (headers) de la solicitud
    headers = {
        "Connection": "keep-alive",
        "X-Platform": "web",
        "Authorization": f"Bearer {bearer_token}",  # Token Bearer editable
        "sec-ch-ua-platform": "\"Windows\"",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6ImZmYTEzMjQ5OGUxNzZhMzciLCJ0ciI6IjQ0NWNkYWI4OGU1YzFjYjhhODlmZWJiMDkyOTdmNTliIiwidGkiOjE3MzI3NzY5NjQ0NDV9fQ==",
        "sec-ch-ua-mobile": "?0",
        "baggage": "sentry-environment=production,sentry-release=e5967f3de92606cfa5faed6b27e5711320af8389,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=71ee1caca0d843a991b316008899b374,sentry-sample_rate=1,sentry-sampled=true",
        "sentry-trace": "71ee1caca0d843a991b316008899b374-a4d6f7a682131ea9-1",
        "traceparent": "00-445cdab88e5c1cb8a89febb09297f59b-ffa132498e176a37-01",
        "X-Refresh-Token": refresh_token,  # Token de refresco editable
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "Content-Type": "application/json",
        "tracestate": "4480399@nr=0-1-4480399-1120323572-ffa132498e176a37----1732776964445",
        "X-Timezone-Offset": "180",
        "Origin": "https://kaiber.ai",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": "https://kaiber.ai/account",
        "Accept-Language": "es-ES,es;q=0.9",
        "Accept-Encoding": "gzip, deflate",
    }

    # Datos que se envían en el cuerpo de la solicitud
    data = {
        "currentPassword": current_password
    }

    # Realizando la solicitud POST
    response = requests.post(url, headers=headers, json=data)

    # Verificando la respuesta
    if response.status_code == 200:
        # Si la respuesta es exitosa, retorna el mensaje
        print(response.json().get("message", "No message in response"))
    else:
        # Si no es exitosa, muestra el error
        print(f"Error {response.status_code}: {response.text}")



def gen_flux_pro_image(prompt, width, height, aspectRatio, model):
    bearer_token = os.environ.get("BEARER_TOKEN")
    refresh_token = os.environ.get("REFRESH_TOKEN")
    uuids = str(uuid.uuid4())
    # Definir la URL y los encabezados de la solicitud
    url = "https://kaiber.ai/api/get_credits"
    headers = {
        "Host": "kaiber.ai",
        "Connection": "keep-alive",
        "X-Platform": "web",
        "Authorization": f"Bearer {bearer_token}",
        "sec-ch-ua-platform": "\"Windows\"",
        "sec-ch-ua": "\"Google Chrome\";v=\"131\", \"Chromium\";v=\"131\", \"Not_A Brand\";v=\"24\"",
        "sec-ch-ua-mobile": "?0",
        "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6IjczY2I2MzFkZWQ3N2RiYmQiLCJ0ciI6ImJlNDZjZGM5ZGY5YTRmM2M3ODBkYjRlMDczZjA4OTNiIiwidGkiOjE3MzMwMDk5MTUwNjV9fQ==",
        "baggage": "sentry-environment=production,sentry-release=3efe4968f941933ebe2c9920e9a021f8740a50bf,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=13801de87c0547ab91fcf9d38f49316d,sentry-sample_rate=1,sentry-sampled=true",
        "sentry-trace": "13801de87c0547ab91fcf9d38f49316d-9b93cf813adb3f97-1",
        "traceparent": "00-be46cdc9df9a4f3c780db4e073f0893b-73cb631ded77dbbd-01",
        "X-Refresh-Token": "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiI2NzRiOTg4MGIwN2YxZTliNWU3NDlhMDYiLCJzaWQiOiI2NzRiOThiYzNkZDNiMzUwMTQ1ZWNmNmEiLCJpYXQiOjE3MzMwMDc1NTEsImV4cCI6MTc0MDc4MzU1MX0.jCJUko3-Hm_FREinCcoC5TcftZP3qnYjOUaDhukn25E",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "tracestate": "4480399@nr=0-1-4480399-1120323572-73cb631ded77dbbd----1733009915065",
        "X-Timezone-Offset": "180",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": f"https://kaiber.ai/superstudio/canvas/{uuids}",
        "Accept-Language": "es-ES,es;q=0.9",
        "Accept-Encoding": "gzip, deflate"
    }

    # Realizar la solicitud GET
    response = requests.get(url, headers=headers)
    
    # Comprobar si la solicitud fue exitosa
    if response.status_code == 200:
        data = response.json()  # Analizar la respuesta JSON

        credits = data.get("credits")  # Extraer el valor de 'credits'

            
        # Validar si los créditos son mayores a 5
        if credits >= 5:
            print(f"Credits válidos: {credits} (mayores a 5)")
            #process_media(bearer_token, refresh_token, model_type, elements_0, elements_1, aspect_ratio, width, height, subject, evolve, version, video_type, motion_magnitude, length, stable_diffusion_checkpoint, guidance, steps, denoise, creativity_scale, loop_video, audio_reactivity, scale_factor, topaz_model, topaz_face_enhancement_creativity, flux_pro_model, prompt_upsampling, form_index, starting_frame_weights, name, userProvidedStartingFrame)
            save_path_flux = send_request_with_boundary(prompt, width, height, aspectRatio, model)
            os.environ["DIR_IMAGEE_FLUX_PRO"] = save_path_flux
            print(save_path_flux)
          
              
        else:
            print(f"Credits insuficientes: {credits} (deben ser mayores a 5)")
            delete_account()
            time.sleep(1)
            register_user()
            user_email = os.environ.get("NAME_EMAIL")
            user_pass = os.environ.get("NAME_PASS")

            bearer_token = os.environ.get("BEARER_TOKEN")
            refresh_token = os.environ.get("REFRESH_TOKEN")


            print("NAME_EMAIL", user_email)
            print("NAME_PASS", user_pass)

            print("BEARER_TOKEN", bearer_token)
            print("REFRESH_TOKEN", refresh_token)
            time.sleep(2)
            save_path_flux = send_request_with_boundary(prompt, width, height, aspectRatio, model)
            os.environ["DIR_IMAGEE_FLUX_PRO"] = save_path_flux
            print(save_path_flux)
          
            
    else:
        print(f"Error: {response.status_code}")
        delete_account()
        time.sleep(1)
        register_user()
        user_email = os.environ.get("NAME_EMAIL")
        user_pass = os.environ.get("NAME_PASS")

        bearer_token = os.environ.get("BEARER_TOKEN")
        refresh_token = os.environ.get("REFRESH_TOKEN")


        print("NAME_EMAIL", user_email)
        print("NAME_PASS", user_pass)

        print("BEARER_TOKEN", bearer_token)
        print("REFRESH_TOKEN", refresh_token)
        time.sleep(2)
        save_path_flux = send_request_with_boundary(prompt, width, height, aspectRatio, model)
        os.environ["DIR_IMAGEE_FLUX_PRO"] = save_path_flux
        print(save_path_flux)
          
def obtener_media_id(json_data):
    # Convertir el string JSON en un diccionario de Python
    data = json.loads(json_data)

    # Extraer y devolver el mediaId
    return data['medias'][0]['mediaId']


def send_request_with_boundary(prompt, width, height, aspectRatio, model):
    bearer_token = os.environ.get("BEARER_TOKEN")
    refresh_token = os.environ.get("REFRESH_TOKEN")
    uuids = str(uuid.uuid4())
    url = "https://kaiber.ai/api/v1/media/process_media"
    headers = {
        "Host": "kaiber.ai",
        "Connection": "keep-alive",
        "X-Platform": "web",
        "Authorization": f"Bearer {bearer_token}",
        "sec-ch-ua-platform": '"Windows"',
        "sec-ch-ua": '"Chromium";v="130", "Google Chrome";v="130", "Not?A_Brand";v="99"',
        "newrelic": "eyJ2IjpbMCwxXSwiZCI6eyJ0eSI6IkJyb3dzZXIiLCJhYyI6IjQ0ODAzOTkiLCJhcCI6IjExMjAzMjM1NzIiLCJpZCI6ImUzOGE1MmM3NjI4MjBhMTQiLCJ0ciI6ImI4NjVhNzM0YTU0M2FkN2U4NDBlMDE4ZjgyZTdhOTFhIiwidGkiOjE3MzQxNDg3Mzk5MDd9fQ==",
        "sec-ch-ua-mobile": "?0",
        "baggage": "sentry-environment=production,sentry-release=fbb2febb8a343bc0cab9f2ea0793358a4d93fc58,sentry-public_key=9348ec458b83e7582c3a35f036e91604,sentry-trace_id=bec753bb5c3a4081ac13bd16e9e17026,sentry-sample_rate=1,sentry-sampled=true",
        "sentry-trace": "bec753bb5c3a4081ac13bd16e9e17026-bd944097d447ac5f-1",
        "traceparent": "00-b865a734a543ad7e840e018f82e7a91a-e38a52c762820a14-01",
        "X-Refresh-Token": refresh_token,
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "Content-Type": "multipart/form-data; boundary=----WebKitFormBoundary8Ut7Azp3unSEiHyl",
        "tracestate": "<VALOR>",
        "X-Timezone-Offset": "180",
        "Origin": "https://kaiber.ai",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-Mode": "cors",
        "Sec-Fetch-Dest": "empty",
        "Referer": f"https://kaiber.ai/superstudio/canvas/{uuids}",
        "Accept-Language": "es-ES,es;q=0.9",
    }

    data = (
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"mediaIds[]\"\r\n\r\n"
        f"{uuids}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[modelType]\"\r\n\r\n"
        "FluxImage\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[elements][0]\"\r\n\r\n"
        "prompt\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[elements][1]\"\r\n\r\n"
        "fluxImageSettings\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][subject]\"\r\n\r\n"
        f"{prompt}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][seed]\"\r\n\r\n"
        "-1\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][safety_tolerance]\"\r\n\r\n"
        "2\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][type]\"\r\n\r\n"
        "Image\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][width]\"\r\n\r\n"
        f"{width}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][height]\"\r\n\r\n"
        f"{height}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][promptUpsampling]\"\r\n\r\n"
        "true\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][fluxProModel]\"\r\n\r\n"
        f"{model}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"flow[formValues][aspectRatio]\"\r\n\r\n"
        f"{aspectRatio}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl\r\n"
        "Content-Disposition: form-data; name=\"fluxImageArgs[prompt]\"\r\n\r\n"
        f"{prompt}\r\n"
        "------WebKitFormBoundary8Ut7Azp3unSEiHyl--"
    )

    response = requests.post(url, headers=headers, data=data)

    if response.status_code == 200:
        json_response = response.json()
        # Extraer la URL del campo 'source'
        if 'medias' in json_response and len(json_response['medias']) > 0:
            source_url = json_response['medias'][0].get('source', None)
            if source_url:
                print(f"Image URL: {source_url}")

                # Crear carpeta si no existe
                img_dir = "/content/img_flux_pro"
                os.makedirs(img_dir, exist_ok=True)

                # Descargar la imagen
                img_path = os.path.join(img_dir, f"{uuids}.jpg")
                try:
                    img_response = requests.get(source_url, stream=True)
                    if img_response.status_code == 200:
                        with open(img_path, "wb") as img_file:
                            for chunk in img_response.iter_content(1024):
                                img_file.write(chunk)
                        #print(f"Image downloaded successfully: {img_path}")
                except Exception as e:
                    print(f"Error downloading image: {e}")
            else:
                print("No 'source' field found in the response.")
        else:
            print("No media data found in the response.")
    else:
        print(f"Request failed with status code {response.status_code}: {response.text}")
    return img_path



#@title login
import requests
import os
import time

def obtener_tokens(bearer_token):
    # URL del endpoint
    url = "https://kaiber.ai/api/auth/me"

    # Encabezados necesarios para la solicitud
    headers = {
        "Authorization": f"Bearer {bearer_token}",  # Inserta el token de autorización
        "X-Platform": "web",
        "sec-ch-ua-platform": "Windows",
        "sec-ch-ua": 'Google Chrome";v="131", "Chromium";v="131", "Not_A Brand";v="24"',
        "sec-ch-ua-mobile": "?0",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        
    }

    # Realizamos la solicitud GET
    response = requests.get(url, headers=headers)

    if response.status_code == 200:
        # Si la respuesta es exitosa, extraemos los tokens del JSON
        data = response.json()  # Convertir la respuesta a JSON
        token = data.get("token")
        refresh_token = data.get("refreshToken")

        return token, refresh_token
    else:
        print("Error en la solicitud:", response.status_code)
        return None, None


import os
import requests
import time

def login_to_kaiber(email, password):
    # Validar valores de entrada
    if not email or not password:
        raise ValueError("El correo electrónico y la contraseña son obligatorios.")
    
    os.environ["NAME_EMAIL"] = email
    os.environ["NAME_PASS"] = password
    url = "https://kaiber.ai/api/auth/login"

    headers = {
        "Host": "kaiber.ai",
        "Connection": "keep-alive",
        "X-Platform": "web",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json, text/plain, */*",
        "Content-Type": "application/json",
        "Origin": "https://kaiber.ai",
        "Referer": "https://kaiber.ai/login",
        "Accept-Language": "es-ES,es;q=0.9"
    }

    payload = {
        "email": email,
        "password": password
    }

    response = requests.post(url, headers=headers, json=payload)

    if response.status_code == 200:
        response_data = response.json()
        token = response_data.get('token', None)

        if not token:
            print("Error: No se encontró el token en la respuesta.")
            return

        time.sleep(3)
        bearer_token, refresh_token = obtener_tokens(token)

        if bearer_token and refresh_token:
            os.environ["BEARER_TOKEN"] = bearer_token
            os.environ["REFRESH_TOKEN"] = refresh_token
        else:
            print("No se pudieron obtener los tokens.")
            os.environ["BEARER_TOKEN"] = None
            os.environ["REFRESH_TOKEN"] = None

    elif response.status_code == 401:
        print("Credenciales incorrectas: Verifica tu correo electrónico y contraseña.")
        os.environ["BEARER_TOKEN"] = None
        os.environ["REFRESH_TOKEN"] = None

    else:
        print(f"Error en la solicitud: {response.status_code} - {response.text}")
        os.environ["BEARER_TOKEN"] = None
        os.environ["REFRESH_TOKEN"] = None



import requests
import os
import uuid

def upload_file_remove(file_path):

    url = "https://api5g.iloveimg.com/v1/upload"
    headers = {
        "Authorization": "Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiIiLCJhdWQiOiIiLCJpYXQiOjE1MjMzNjQ4MjQsIm5iZiI6MTUyMzM2NDgyNCwianRpIjoicHJvamVjdF9wdWJsaWNfYzkwNWRkMWMwMWU5ZmQ3NzY5ODNjYTQwZDBhOWQyZjNfT1Vzd2EwODA0MGI4ZDJjN2NhM2NjZGE2MGQ2MTBhMmRkY2U3NyJ9.qvHSXgCJgqpC4gd6-paUlDLFmg0o2DsOvb1EUYPYx_E",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36",
        "Accept": "application/json"
    }

    # Archivos y datos para enviar en la solicitud
    files = {
        "file": (file_path.split('/')[-1], open(file_path, "rb"), "image/png")
    }
    data = {
        "name": file_path.split('/')[-1],
        "chunk": "0",
        "chunks": "1",
        "task": "gyhlpbxfbv92Asq51kA9412wtnzfsbpj8fd0rsrspk86jxfs1bjph66qqgl0nlpgAk6mxlxc16kn9xr1p6ccw36m7gzkjmbAllnptwdm2rgc8qtxd2slc9716AkdsA1cfv8txz2rn87y1dtpz0bxtA6rl0qc5lkssts00jzf5jp79y47dszq",
        "preview": "1",
        "pdfinfo": "0",
        "pdfforms": "0",
        "pdfresetforms": "0",
        "v": "web.0"
    }

    # Hacer la solicitud POST
    try:
        response = requests.post(url, headers=headers, files=files, data=data)
        response.raise_for_status()  # Elevar una excepción si hay un error HTTP
        json_response = response.json()  # Parsear la respuesta como JSON
        server_filenames = json_response.get("server_filename", "No se encontró server_filename")

        if server_filenames:
           os.environ["REMOVE_FILE"] = server_filenames
           
        return json_response.get("server_filename", "No se encontró server_filename")
    except requests.exceptions.RequestException as e:
        return {"error": str(e)}

def remove_image():
    # Ruta de la carpeta
    carpeta = '/content/img_remove'
    # Verifica si la carpeta no existe
    if not os.path.exists(carpeta):
        os.makedirs(carpeta)

    output_path = str(uuid.uuid4())
    server_filename = os.environ.get("REMOVE_FILE")
    api_url = "https://api5g.iloveimg.com/v1/removebackground"

    headers = {
        "Authorization": "Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiIiLCJhdWQiOiIiLCJpYXQiOjE1MjMzNjQ4MjQsIm5iZiI6MTUyMzM2NDgyNCwianRpIjoicHJvamVjdF9wdWJsaWNfYzkwNWRkMWMwMWU5ZmQ3NzY5ODNjYTQwZDBhOWQyZjNfT1Vzd2EwODA0MGI4ZDJjN2NhM2NjZGE2MGQ2MTBhMmRkY2U3NyJ9.qvHSXgCJgqpC4gd6-paUlDLFmg0o2DsOvb1EUYPYx_E",
        "Accept": "*/*"
    }
    
    # Datos del formulario
    data = {
        "task": "gyhlpbxfbv92Asq51kA9412wtnzfsbpj8fd0rsrspk86jxfs1bjph66qqgl0nlpgAk6mxlxc16kn9xr1p6ccw36m7gzkjmbAllnptwdm2rgc8qtxd2slc9716AkdsA1cfv8txz2rn87y1dtpz0bxtA6rl0qc5lkssts00jzf5jp79y47dszq",
        "server_filename": server_filename
    }

    try:
        # Realizar la solicitud POST
        response = requests.post(api_url, headers=headers, data=data)
        response.raise_for_status()  # Verifica errores HTTP

        # Guardar la respuesta como archivo de imagen
        with open(f"/content/img_remove/{output_path}.png", "wb") as file:
            file.write(response.content)
        
        os.environ["IMAGE_REMOVE"] = f"/content/img_remove/{output_path}.png"
        print(f"Imagen escalada guardada en: {output_path}.png")
    except requests.exceptions.RequestException as e:
        print(f"Error al realizar la solicitud: {e}")


from setuptools import setup, find_packages

setup(
    name='gradio-uploader',
    version='1.0.0',
    author='IA (Sistema de Intres)',
    author_email='system.ai.of.interest@gmail.com',
    description='esta libreria fue creada por IA Sistema de Intres',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://www.youtube.com/@IA.Sistema.de.Interes',  # Opcional, pero recomendado
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'requests',
        'tqdm',
        'Pillow',
        'IPython',
    ],
)